@@ -1,12 +1,11 @@
 #!/bin/sh
 
 echo "*** This is upgrade script for Tucnak"
-echo "*** Please follow instructions bellow"
+echo "*** Please follow instructions below"
 echo ""
 
-cmd="sudo LANG= LC_ALL= dpkg -i '$1' '$2'"
-echo $cmd
-$cmd
+echo "sudo LANG= LC_ALL= dpkg -i '$1' '$2'"
+LANG= LC_ALL= sudo dpkg -i "$1" "$2"
 if test x"$?" = x"0" ; then
     echo "*** Seems OK. Please restart Tucnak"
     exit 0
@@ -15,8 +14,9 @@ else
 fi
 
 
-echo su -p -c dpkg -i "$1" "$2" root
-su -p -c 'LANG= LC_ALL= dpkg -i "$1" "$2"' root
+echo "*** Please enter root's password"
+echo su -l -c dpkg -i "$1" "$2" root
+su -l -c "dpkg -i \"$1\" \"$2\"" root
 if test x"$?" = x"0" ; then
     echo "*** Seems OK. Please restart Tucnak"
     exit 0
