@@ -30,7 +30,9 @@
 #include "subwin.h"
 #include "tsdl.h"
 
-#include <math.h>
+#ifdef HAVE_MATH_H
+#define _USE_MATH_DEFINES // for MSVC
+#endif
 
 struct its{
     double kx, ky;
@@ -766,7 +768,7 @@ gpointer acs_thread(gpointer arg){
     int new_tmpctp = 0;
     int new_infoctp = 0;
 
-    zg_thread_set_name("Tucnak A/C");
+    zg_thread_set_name("Tucnak AS");
     while (!acs->thread_break){
         char *data;
         struct ac *ac;
@@ -779,7 +781,7 @@ gpointer acs_thread(gpointer arg){
             usleep(100000);
         }
 
-        dbg("------acs_thread--------\n");
+        //dbg("------acs_thread--------\n");
 
         MUTEX_LOCK(acs->sh);
         if (acs->sh.data){
@@ -858,7 +860,7 @@ gpointer acs_thread(gpointer arg){
                 /*if (strcmp(qi->call, "S57C") == 0){
                     int aa = 0;
                 } */
-                dbg("acs_thread: %3d %s\n", j, qi->call);
+                //dbg("acs_thread: %3d %s\n", j, qi->call);
                 usleep(1000);
                 //ctp->qrb = qi->qrb;
                 hw2qrbqtf(acs->th.myh, acs->th.myw, qth(qi->wwl, 0), qth(qi->wwl, 1), &ctp->qrb, &ctp->qtfrad); 
