@@ -121,12 +121,19 @@ static int write_adif_qsos(struct band *b, struct config_band *confb, FILE *f){
     
     for (i=0; i<b->qsos->len; i++){
         q = get_qso(b, i); 
+	if (q->error && cfg->adif_export_mode_t2r == 2){
+	    continue;
+	}
         
         ADIF_STR_UC("BAND",confb->adifband);
         ADIF_DATE  ("QSO_DATE",q->date_str);
         ADIF_STR   ("TIME_ON",q->time_str);
         if (q->error){
-            ADIF_STR_UC("CALL","ERROR");
+            if (cfg->adif_export_mode_t2r == 1){
+                ADIF_STR_UC("CALL",q->callsign);
+            }else{
+                ADIF_STR_UC("CALL","ERROR");
+            }
         }else{
             ADIF_STR_UC("CALL",q->callsign);
         }
@@ -392,6 +399,7 @@ static int adif_add_qso(struct band *band, GHashTable *hash){
     q->stamp=time(NULL);
 
     q->remark=fixsemi(g_strdup(SAFE_ADIF_ITEM("COMMENT")));
+	q->phase = 1;
     q->ser_id=-1; /* computed by add_qso_to_index */
     compute_qrbqtf(q);
     add_qso(b, q);
