@@ -83,8 +83,10 @@ void do_menu_selected(struct menu_item *items, void *data, int selected)
     } else if (items->free_i) {
         int i;
         for (i = 0; items[i].text; i++) {
-            if (items[i].free_i & 2) g_free(items[i].text);
-            if (items[i].free_i & 4) g_free(items[i].rtext);
+            if (items[i].free_i & 2) 
+				g_free(items[i].text);
+            if (items[i].free_i & 4) 
+				g_free(items[i].rtext);
         }
         g_free(items);
     }
@@ -359,8 +361,10 @@ void menu_func(struct window *win, struct event *ev, int fwd)
             if (menu->items->free_i) {
                 int i;
                 for (i = 0; menu->items[i].text; i++) {
-                    if (menu->items[i].free_i & 2) g_free(menu->items[i].text);
-                    if (menu->items[i].free_i & 4) g_free(menu->items[i].rtext);
+                    if (menu->items[i].free_i & 2) 
+						g_free(menu->items[i].text);
+                    if (menu->items[i].free_i & 4) 
+						g_free(menu->items[i].rtext);
                 }
                 g_free(menu->items);
             }
