@@ -61,7 +61,7 @@ void sw_chart_choose(struct menu *menu){
 	for (i = 0; i < menu->ni; i++){
 		struct menu_item *mi = menu->items + i;
 		if (!mi->checked) continue;
-		filename = g_strdup_printf("%s/%s/c.txt", tucnak_dir, (char *)mi->data);
+		filename = g_strdup_printf("%s/%s/c.txt", logs_dir, (char *)mi->data);
 		chart_import_edi(NULL, filename);
 		g_free(filename);
 	}
@@ -609,7 +609,7 @@ int sw_chart_recalc_extremes(struct subwin *sw, struct band *band){
         }
     }
 	
-	sw->mint = (sw->mint / 60) * 60;
+	if (sw->mint != 1000000000) sw->mint = (sw->mint / 60) * 60;
 	sw->maxt = ((sw->maxt + 59) / 60) * 60;
 #endif
 	return 0;
