@@ -20,7 +20,7 @@
 #include "session.h"
 #include "terminal.h"
 
-static char *strstates[]={"RUN","SP","REQR","REQS","RUNING","GIVEN"};
+static char *strstates[]={"RUN","SP","REQR","REQS","RUNNING","GIVEN"};
 static char *strccmds[]={"REQ","ACC","REJ","BACK"};
 
 
@@ -82,7 +82,7 @@ void menu_grabband(void *cba){
             g_free(c);
             break;
         case CTRL_REQS:
-        case CTRL_RUNING: /* see ctrl_back */
+        case CTRL_RUNNING: /* see ctrl_back */
             b->ctrlstate=CTRL_SP;
             c=g_strdup_printf("GR %s;%d;%s\n", b->pband, CCMD_BACK, gnet->myid);
             dbg("   send %s",c);
@@ -129,13 +129,13 @@ void net_grab(struct band *b, enum ccmd ccmd, gchar *netid){
         /* S&P */            
         case CTRL_SP:
         case CTRL_REQS:
-        case CTRL_RUNING:
+        case CTRL_RUNNING:
             switch(ccmd){
                 case CCMD_ACC:
                     if (strcmp(netid,gnet->myid)) {
                         b->ctrlstate=CTRL_SP;       /* other S&P become control */
                     }else{
-                        b->ctrlstate=CTRL_RUNING;
+                        b->ctrlstate=CTRL_RUNNING;
                     }
                     break;
                 case CCMD_REJ:
@@ -163,8 +163,8 @@ void ctrl_back(struct band *b){
         /* S&P */            
         case CTRL_SP:
         case CTRL_REQS:
-        case CTRL_RUNING:
-            /* see menu_grabband/CTRL_RUNING */
+        case CTRL_RUNNING:
+            /* see menu_grabband/CTRL_RUNNING */
             b->ctrlstate=CTRL_SP;
             c=g_strdup_printf("GR %s;%d;%s\n", b->pband, CCMD_BACK, gnet->myid);
             dbg("   send %s",c);
