@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -189,14 +189,14 @@ static void save_one_cw(gpointer key, gpointer value, gpointer user_data){
     if (cwi->wwl0){ 
         sprintf(s, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
         g_string_append(gs, s);
-        // g_string_sprintfa is incredibely slow under msvc
-        //g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
+        // g_string_append_printf is incredibely slow under msvc
+        //g_string_append_printf(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
     }
     
     if (cwi->wwl1){
         sprintf(s, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
         g_string_append(gs, s);
-        //g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
+        //g_string_append_printf(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
     }
     
 }
@@ -265,14 +265,14 @@ static void format_one_cw(gpointer key, gpointer value, gpointer user_data){
     if (cwi->wwl0){ 
         sprintf(s, "%s %s %d %s;", call, cwi->wwl0, cwi->stamp0, qrv_str);
         g_string_append(gs, s);
-        // g_string_sprintfa is incredibely slow under msvc
-        //g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
+        // g_string_append_printf is incredibely slow under msvc
+        //g_string_append_printf(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl0, cwi->stamp0, qrv_str);
     }
     
     if (cwi->wwl1){
         sprintf(s, "%4s %s %d %s;", call, cwi->wwl1, cwi->stamp1, qrv_str);
         g_string_append(gs, s);
-        //g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
+        //g_string_append_printf(gs, "%-14s %-6s %08d %s\n", call, cwi->wwl1, cwi->stamp1, qrv_str);
     }
     
 }
@@ -744,12 +744,12 @@ int cwdb_call_info(GString *gs, gchar *call, gchar *stroke, GHashTable *wwls){
      /* wwl0 should be always defined */
     if (cwi->wwl0) {
         qrbqtf(myqth, cwi->wwl0, &qrb, &qtf, NULL, 0);
-        g_string_sprintfa(gs, "C_W: %-10s %s %6dkm %3d%s  %d\n", c, cwi->wwl0, (int)qrb, (int)qtf, degree, cwi->stamp0);
+        g_string_append_printf(gs, "C_W: %-10s %s %6dkm %3d%s  %d\n", c, cwi->wwl0, (int)qrb, (int)qtf, degree, cwi->stamp0);
         if (wwls && g_hash_table_lookup(wwls, cwi->wwl0) == NULL) g_hash_table_insert(wwls, cwi->wwl0, NULL);
     }
     if (cwi->wwl1) {
         qrbqtf(myqth, cwi->wwl1, &qrb, &qtf, NULL, 0);
-        g_string_sprintfa(gs, "C_W: %-10s %s %6dkm %3d%s  %d\n", c, cwi->wwl1, (int)qrb, (int)qtf, degree, cwi->stamp1);
+        g_string_append_printf(gs, "C_W: %-10s %s %6dkm %3d%s  %d\n", c, cwi->wwl1, (int)qrb, (int)qtf, degree, cwi->stamp1);
         if (wwls && g_hash_table_lookup(wwls, cwi->wwl1) == NULL) g_hash_table_insert(wwls, cwi->wwl1, NULL);
     }
     if (cwi->qrv>0){
