@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -247,60 +247,60 @@ void usb_info(GString *gs){
     unsigned char eeprom_buf[128];
 #endif
     
-    g_string_sprintfa(gs, "\n  usb_info:\n");
+    g_string_append_printf(gs, "\n  usb_info:\n");
     ret = ftdi_init(&ftdi); 
     if (ret < 0) {
-        g_string_sprintfa(gs, "error calling ftdi_init, error=%d %s", ret, ftdi_get_error_string(&ftdi));
+        g_string_append_printf(gs, "error calling ftdi_init, error=%d %s", ret, ftdi_get_error_string(&ftdi));
         return;
     }
     for (idi = 0; ids[idi] != 0; idi += 2){
         ret = ftdi_usb_find_all(&ftdi, &list, ids[idi], ids[idi+1]);
         if (ret < 0) {
-            g_string_sprintfa(gs, "error calling ftdi_usb_find_all, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
+            g_string_append_printf(gs, "error calling ftdi_usb_find_all, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
             return;
         }
         if (ret == 0) continue;
         for (dev = list; dev != NULL; dev = dev->next){
-            // FIXME g_string_sprintfa(gs, "%04x:%04x  ", dev->dev->descriptor.idVendor, dev->dev->descriptor.idProduct);
+            // FIXME g_string_append_printf(gs, "%04x:%04x  ", dev->dev->descriptor.idVendor, dev->dev->descriptor.idProduct);
 #ifdef Z_HAVE_FTDI_USB_GET_STRINGS
             ret = ftdi_usb_get_strings(&ftdi, dev->dev, manufacturer, 128, description, 128, serial, 128);
             if (ret < 0){
-                g_string_sprintfa(gs, "Can't get strings, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
+                g_string_append_printf(gs, "Can't get strings, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
             }else{
-                g_string_sprintfa(gs, "%s %s ", manufacturer, description);
+                g_string_append_printf(gs, "%s %s ", manufacturer, description);
                 if (strlen(serial)>0 && serial[0]!='?')
-                    g_string_sprintfa(gs, "%s  ", serial);
+                    g_string_append_printf(gs, "%s  ", serial);
             }
 #endif
             if (ids[idi] == 0x04D8){
-                g_string_sprintfa(gs, "\n");
+                g_string_append_printf(gs, "\n");
                 continue;
             }
             ret = ftdi_usb_open_dev(&ftdi, dev->dev);
             if (ret < 0){
-                g_string_sprintfa(gs, "Can't open device, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
+                g_string_append_printf(gs, "Can't open device, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
             }else{
                 g_string_append(gs, "Open OK ");
 #ifdef DUMP_EEPROM
                 ret = ftdi_read_eeprom(&ftdi, eeprom_buf);
                 if (ret < 0){
-                    g_string_sprintfa(gs, "Can't open device, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
+                    g_string_append_printf(gs, "Can't open device, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
                 }else{
                     int i;
                     unsigned short chksum_in_eeprom, chksum_computed;
                     for (i=0; i<128; i++){
-                        g_string_sprintfa(gs, "%02x ", (unsigned char)eeprom_buf[i]);
-                        if (i%16==15) g_string_sprintfa(gs, "\n");
+                        g_string_append_printf(gs, "%02x ", (unsigned char)eeprom_buf[i]);
+                        if (i%16==15) g_string_append_printf(gs, "\n");
                         
                     }
                     chksum_in_eeprom = eeprom_buf[0x7e] + 256 * eeprom_buf[0x7f];
                     chksum_computed = ftdi_checksum(eeprom_buf, 0x80);
-                    g_string_sprintfa(gs, "Checksum eeprom=%04x computed=%04x ", chksum_in_eeprom, chksum_computed);
+                    g_string_append_printf(gs, "Checksum eeprom=%04x computed=%04x ", chksum_in_eeprom, chksum_computed);
                 }
 #endif
                 ftdi_usb_close(&ftdi);
             }
-            g_string_sprintfa(gs, "\n");
+            g_string_append_printf(gs, "\n");
         }
     }
     ftdi_list_free(&list);
