@@ -21,9 +21,19 @@
 #include <SLES/OpenSLES.h>
 #endif
 
+#ifdef HAVE_SWRADIO
+#include <linux/videodev2.h>
+#endif
+
+#ifdef HAVE_LIBRTLSDR
+#include <rtl-sdr.h>
+#endif
+
 #define MAX_CHANNELS 4
 
-enum dsp_type { DSPT_OSS, DSPT_ALSA, DSPT_SSBDx, DSPT_PORTAUDIO, DSPT_SNDFILE, DSPT_SNDPIPE, DSPT_SDRC };
+enum dsp_type { DSPT_OSS, DSPT_ALSA, DSPT_SSBDx, DSPT_PORTAUDIO, 
+    DSPT_SNDFILE, DSPT_SNDPIPE, DSPT_SDRC, DSPT_SWRADIO,
+    DSPT_RTLSDR };
 
 enum dsp_cfg_group { DCG_SSBD, DCG_SDR };
 
@@ -33,11 +43,14 @@ struct dsp{
 /* OSS only */    
 #ifdef HAVE_SYS_SOUNDCARD_H
     char *oss_filename, *oss_mixer;
-    int fd;
     int fmt_mask;
     int oss_format,fragment,blksize;
 #endif
 
+#if defined(HAVE_SYS_SOUNDCARD_H) || defined(HAVE_SWRADIO)
+    int fd;
+#endif
+
 /* Alsa only */    
 #ifdef HAVE_ALSA    
     snd_pcm_t *pcm;
@@ -65,6 +78,19 @@ struct dsp{
     SLObjectItf bqPlayerBufferQueue;
 #endif	
 
+#ifdef HAVE_SWRADIO
+	char *swradio_filename;
+    uint32_t swradio_format;
+#endif
+
+#ifdef HAVE_LIBRTLSDR
+	char *rtlsdr_device;
+	rtlsdr_dev_t *rtlsdr_dev;
+	uint32_t rtlsdr_frequency;
+	unsigned char *rtlsdr_buf;
+	//int rtlsdr_bufsize, rtlsdr_buflen, rtlsdr_bufhead; // all in bytes
+#endif
+
 #ifdef HAVE_SNDFILE
 	SNDFILE *sndfile;
 	SF_INFO *sfinfo;
