@@ -244,7 +244,7 @@ int load_dw_from_file(struct dw *dw, gchar *filename){
 int load_dw_from_mem(struct dw *dw, const char *file, const long int len){
     GString *pref, *wwls, *centers; 
     gchar *dxc, *prefix, *wwl, *c0, *c1;
-    struct dw_item *dxci;
+    struct dw_item *dxci, *maindxci;
     char *token_ptr;
 	long int pos;
 
@@ -281,8 +281,12 @@ int load_dw_from_mem(struct dw *dw, const char *file, const long int len){
         
         c1 = strtok_r(NULL, DW_DELIM, &token_ptr);
             
-
-        dxci = add_dxc(dw, dxc, c0, c1, 0, 0, NULL, NULL, 404, 404); 
+		maindxci = get_dw_item_by_call(dw, dxc);
+		if (maindxci){
+			dxci = add_dxc(dw, dxc, c0, c1, maindxci->waz, maindxci->itu, maindxci->continent, maindxci->dxcname, maindxci->latitude, maindxci->longitude);
+		}else{
+			dxci = add_dxc(dw, dxc, c0, c1, 0, 0, NULL, NULL, 404, 404);
+		}
         
         add_dw(dxci, dxc, c0);
         add_dw(dxci, dxc, c1);
@@ -916,7 +920,7 @@ void call_info(void *arg){
         qso->qsonrs = "";
         qso->rstr = "";
         qso->qsonrr = "";
-        qso_info(qso, gs, gs2);
+		qso_info(qso, gs, gs2);
 		freeqso=1;
     }else if (aband && (!TMPQ.callsign || !strlen(TMPQ.callsign))){
         if (aband->qsos->len<=0) goto x;
@@ -931,7 +935,7 @@ void call_info(void *arg){
         qso->qsonrs = TMPQ.qsonrs?TMPQ.qsonrs:"";
         qso->rstr = TMPQ.rstr?TMPQ.rstr:"";
         qso->qsonrr = TMPQ.qsonrr?TMPQ.qsonrr:"";
-        qso_info(qso, gs, gs2);
+		qso_info(qso, gs, gs2);
 		freeqso=1;
     }else{
         goto x;
@@ -1141,6 +1145,6 @@ char *get_pref(char *buf, const char *call){
     if (c0) g_free(c0);
 	if (c1) g_free(c1);
 	if (c2) g_free(c2);
-    dbg("get_pref(%s)='%s'\n", call, buf);
+    //dbg("get_pref(%s)='%s'\n", call, buf);
     return buf;
 }
