@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 #include "net.h"
 #include "qrvdb.h"
 #include "qsodb.h"
+#include "rain.h"
 #include "session.h"
 #include "sked.h"
 #include "stats.h"
@@ -120,6 +121,8 @@ void add_qso_str3(GString *gs, struct qso *q, struct band *b){
     g_string_append_printf(gs, ";%d", q->ser_id);
     
     g_string_append_printf(gs, ";%1.0f", q->qrg);
+
+	g_string_append_printf(gs, ";%d", q->phase);
 }
 
 
@@ -255,7 +258,8 @@ static int write_edi_remarks(struct band *b, struct config_band *confb, FILE *f)
     g_string_append_printf(gs, "wwlcfm=%d\r\n", ctest->wwlcfm);
     g_string_append_printf(gs, "tttype=%d\r\n", ctest->tttype);
     g_string_append_printf(gs, "expmode=%d\r\n", ctest->expmode);
-    
+	g_string_append_printf(gs, "phase=%d\r\n", ctest->phase);
+
     g_string_append_printf(gs, "bandchar=%c\r\n", b->bandchar);
 //    g_string_append_printf(gs, "bandmulti=%d\r\n", b->bandmulti);
     g_string_append_printf(gs, "mode=%d\r\n", gses->mode);
@@ -800,12 +804,6 @@ static void add_qsos_from_mem(struct band *b, GHashTable *hash, GPtrArray *qsos,
             q->remark   = g_strdup("");
         }else{
             q->remark   = g_strdup(items[5]);
-
-            if (!items[6]){
-                q->qrg = 0.0;
-            }else{
-                q->qrg = atof(items[6]);
-            }
         }
 
         if (q->error && *items[3]){
@@ -833,6 +831,15 @@ static void add_qsos_from_mem(struct band *b, GHashTable *hash, GPtrArray *qsos,
         }else{
             q->qrg = 0.0; 
         }
+
+		if (items[6] && items[7] && items[8]){
+			q->phase = atoi(items[8]);
+			if (q->phase > ctest->phase) 
+				ctest->phase = q->phase;
+		}
+		else{
+			q->phase = 1;
+		}
         
         g_strfreev(items);
         compute_qrbqtf(q);
@@ -968,7 +975,7 @@ void load_contest_edi(const gchar *date, int edi){
     
 	progress(VTEXT(T_LOADING_CONTEST), date);
 
-    c=g_strdup_printf("%s/%s/desc.lock", tucnak_dir, date);
+    c=g_strdup_printf("%s/%s/desc.lock", logs_dir, date);
 	z_wokna(c);
     lockfile = fopen(c, "w");
     if (!lockfile){
@@ -989,7 +996,7 @@ void load_contest_edi(const gchar *date, int edi){
                 
     
     
-    datedir = g_strdup_printf("%s/%s", tucnak_dir, date);
+    datedir = g_strdup_printf("%s/%s", logs_dir, date);
    
     file = g_strdup_printf("%s/log", datedir);
     load_fifo_from_file(glog, file,0);
@@ -997,7 +1004,7 @@ void load_contest_edi(const gchar *date, int edi){
     zg_free0(file);
 
 	progress(VTEXT(T_LOADING_LOGFILE));
-    c=g_strdup_printf("%s/%s/log", tucnak_dir, date);
+    c=g_strdup_printf("%s/%s/log", logs_dir, date);
     logfile = fopen(c, "at");
     if (!logfile){
         g_snprintf(ss,1000, VTEXT(T_CANT_OPEN_S),c);
@@ -1088,6 +1095,7 @@ destroy:;
             maps_reload();
 			maps_update_showwwls();
             chart_reload();
+			rain_reload();
         }
         
         b = init_band(NULL, hash, NULL, NULL);
