@@ -360,5 +360,25 @@ void fifo_message(void *itdata, void *menudata){
 	sw_kst_message(itdata, sw);
 }
 
+void fifo_kst_info(void *itdata, void *menudata){
+	if (!gses) return;
+
+	struct subwin *sw = sw_raise_or_new(SWT_KST);
+	sw_set_focus();
+	sw->callunder = g_strdup(gses->callunder);
+	sw_kst_info(itdata, sw);
+}
+
+#ifdef Z_HAVE_SDL
+void fifo_kst_ac_info(void *itdata, void *menudata){
+	if (!gses) return;
+
+	struct subwin *sw = sw_raise_or_new(SWT_KST);
+	sw_set_focus();
+	sw->callunder = g_strdup(gses->callunder);
+	sw_kst_ac_info(itdata, sw);
+}
+#endif
+
 
 
