@@ -175,11 +175,9 @@
 
 
 
-/*#ifdef Z_HAVE_SDL
-#include <SDL.h>
-#include <SDL_thread.h>
-#include <SDL_endian.h>
-#endif*/
+#if defined(Z_HAVE_SDL) && !defined(Z_HAVE_SDL1) && !defined(Z_HAVE_SDL2) 
+#error Undefined SDL version
+#endif
 
 
 #ifdef HAVE_SYS_SOUNDCARD_H
@@ -571,6 +569,11 @@ extern char *txt_settings;
 int export_all_bands_cbr(void);
 
 
+/* stf.c */
+
+int export_all_bands_stf(void);
+
+
 /* list.c */
 
 void import_list(void *xxx, char *filename);
