@@ -25,7 +25,7 @@ struct subwin;
 
 gchar *qh(GString *gs, gchar *s);
 void html_style(GString *gs);
-void html_header(GString *gs, gchar *title, int flags, char *bodyarg);
+void html_header(GString *gs, gchar *title, int flags, int refresh, char *bodyarg);
 void html_ref_header(GString *gs);
 void html_band_ref(GString *gs, struct band *b, struct config_band *confb);
 void html_ref_footer(GString *gs, struct band *b, struct config_band *confb);
