@@ -1,6 +1,6 @@
 /*
     httpd.c - Contest progress displayed via http
-    Copyright (C) 2011-2015 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2020 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -170,7 +170,7 @@ void httpd_read_handler(void *arg){
         httpd_get(conn);
     }else{
         httpd_header(conn, 400, NULL);
-        g_string_sprintf(conn->response, "<html><body>Bad request</body></html>");
+        g_string_printf(conn->response, "<html><body>Bad request</body></html>");
     }
 /*    for (i = 0; i < 1000; i++){
         g_string_append_c(conn->response, '0' + (i / 100));
@@ -233,11 +233,11 @@ void httpd_header(struct httpconn *conn, int status, char *contenttype){
         default: ss = "Unknown status"; break;
     }
 
-    g_string_sprintf(conn->response, "HTTP/1.1 %d %s\r\n", status, ss);
-    g_string_sprintfa(conn->response, "Server: Tucnak-%s %s\r\n", Z_PLATFORM, PACKAGE_VERSION);
-    g_string_sprintfa(conn->response, "Connection: close\r\n");
-    g_string_sprintfa(conn->response, "Content-Type: %s\r\n", contenttype);
-    g_string_sprintfa(conn->response, "\r\n");
+    g_string_printf(conn->response, "HTTP/1.1 %d %s\r\n", status, ss);
+    g_string_append_printf(conn->response, "Server: Tucnak-%s %s\r\n", Z_PLATFORM, PACKAGE_VERSION);
+    g_string_append_printf(conn->response, "Connection: close\r\n");
+    g_string_append_printf(conn->response, "Content-Type: %s\r\n", contenttype);
+    g_string_append_printf(conn->response, "\r\n");
 
 }
 
@@ -314,7 +314,7 @@ static void httpd_get_index(struct httpconn *conn){
 
     if (!ctest){
         html_header(conn->response, "No contest", HTML_ICON, httpd->refresh, NULL);
-        g_string_sprintfa(conn->response, "<p>No contest opened</p>\n");
+        g_string_append_printf(conn->response, "<p>No contest opened</p>\n");
         html_footer(conn->response, 0);
         return;
     }
@@ -325,26 +325,26 @@ static void httpd_get_index(struct httpconn *conn){
     zg_string_eprintfa("h", title, "%S - %s", ctest->pcall, ctest->tname);
     html_header(gs, title->str, HTML_ICON, httpd->refresh, NULL);
 
-    g_string_sprintfa(gs, "<a href=\"complete\">Complete report</a><br>\n");
-    g_string_sprintfa(gs, "<a href=\"search?q=\">QSO search</a><br>\n");
+    g_string_append_printf(gs, "<a href=\"complete\">Complete report</a><br>\n");
+    g_string_append_printf(gs, "<a href=\"search?q=\">QSO search</a><br>\n");
     for (i = 0; i < ctest->bands->len; i++){
         struct band *b;
         b = (struct band*)g_ptr_array_index(ctest->bands, i);
 
         zg_string_eprintfa("h", gs, "<a name=\"%c\"></a><h2>Band %s</h2>\n", b->bandchar, b->bandname);
-        g_string_sprintfa(gs, "<p>QSOs: %d<br>\n", b->stats->nqsos);
-        g_string_sprintfa(gs, "Points: %d<br>\n", b->stats->ntotal);
-        g_string_sprintfa(gs, "WWLs: %d<br>\n", g_hash_table_size(b->stats->wwls));
-        g_string_sprintfa(gs, "DXCCs: %d<br>\n", g_hash_table_size(b->stats->dxcs));
+        g_string_append_printf(gs, "<p>QSOs: %d<br>\n", b->stats->nqsos);
+        g_string_append_printf(gs, "Points: %d<br>\n", b->stats->ntotal);
+        g_string_append_printf(gs, "WWLs: %d<br>\n", g_hash_table_size(b->stats->wwls));
+        g_string_append_printf(gs, "DXCCs: %d<br>\n", g_hash_table_size(b->stats->dxcs));
         if (b->stats->nqsos){
-            g_string_sprintfa(gs, "AVG: %5.2f pts/qso<br>\n", (double)b->stats->ntotal/(double)b->stats->nqsos);
+            g_string_append_printf(gs, "AVG: %5.2f pts/qso<br>\n", (double)b->stats->ntotal/(double)b->stats->nqsos);
         }
         if (b->stats->odxcall){
             zg_string_eprintfa("h", gs, "ODX: %S %S %d km op %S<br>\n", b->stats->odxcall, b->stats->odxwwl, b->stats->odxqrb_int, b->stats->odxoperator);
         }
-        g_string_sprintfa(gs, "<a href=\"stats/%c\">Statistics</a>\n", b->bandchar);
-        g_string_sprintfa(gs, "<a href=\"qsos/%c\">QSOs</a><br>\n", b->bandchar);
-        g_string_sprintfa(gs, "</p>\n");
+        g_string_append_printf(gs, "<a href=\"stats/%c\">Statistics</a>\n", b->bandchar);
+        g_string_append_printf(gs, "<a href=\"qsos/%c\">QSOs</a><br>\n", b->bandchar);
+        g_string_append_printf(gs, "</p>\n");
 
 
     }
@@ -368,18 +368,18 @@ void httpd_get_stats(struct httpconn *conn, const char *bandchar_str){
     b = find_band_by_bandchar(bandchar_str[0]);
     if (!b){
         html_header(conn->response, VTEXT(T_BAND_NOT_FOUND), HTML_ICON, httpd->refresh, NULL); 
-        g_string_sprintfa(conn->response, VTEXT(T_BAND_NOT_FOUND), bandchar_str[0]);
+        g_string_append_printf(conn->response, VTEXT(T_BAND_NOT_FOUND), bandchar_str[0]);
         html_footer(conn->response, 0);
         return;
     }
 
     html_header(conn->response, VTEXT(T_STATS), HTML_ICON, httpd->refresh, NULL); 
-    g_string_sprintfa(conn->response, "<pre>");
+    g_string_append_printf(conn->response, "<pre>");
     for (i = 0; i < b->statsfifo1->items->len ; i++){
         char *s = (char*)g_ptr_array_index(b->statsfifo1->items, i);
-        g_string_sprintfa(conn->response, "%s\n", s);
+        g_string_append_printf(conn->response, "%s\n", s);
     }
-    g_string_sprintfa(conn->response, "</pre>");
+    g_string_append_printf(conn->response, "</pre>");
     html_footer(conn->response, 0);
 
 }
@@ -402,7 +402,7 @@ void httpd_get_qsos(struct httpconn *conn, const char *bandchar_str){
     confb = get_config_band_by_bandchar(bandchar);
     if (!b || !confb){
         html_header(conn->response, VTEXT(T_BAND_NOT_FOUND), HTML_ICON, httpd->refresh, NULL); 
-        g_string_sprintfa(conn->response, VTEXT(T_BAND_C_NOT_FOUND), bandchar_str[0]);
+        g_string_append_printf(conn->response, VTEXT(T_BAND_C_NOT_FOUND), bandchar_str[0]);
         html_footer(conn->response, 0);
         return;
     }
@@ -543,7 +543,7 @@ void httpd_search_form(struct httpconn *conn){
 
     if (!ctest){
         html_header(conn->response, "No contest", HTML_ICON | HTML_CENTER, NULL); 
-        g_string_sprintfa(conn->response, "<p>No contest opened</p>\n");
+        g_string_append_printf(conn->response, "<p>No contest opened</p>\n");
         g_string_append(gs, "<br><br><br>\n");
         html_footer(conn->response, HTML_CENTER);
         return;
@@ -593,7 +593,7 @@ void httpd_search(struct httpconn *conn, char *call){
     ctest->pcall, ctest->tname);*/
 
     if (strlen(call)){
-        g_string_sprintfa(gs, 
+        g_string_append_printf(gs, 
             "<table class=\"qsos\">"
             "<tr><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th></tr>", VTEXT(T_BAND2), VTEXT(T_DATE2), VTEXT(T_UTC), VTEXT(T_CALL), VTEXT(T_INFO));
 
@@ -614,7 +614,7 @@ void httpd_search(struct httpconn *conn, char *call){
         }
 
         g_string_append(gs, "</table>");
-        if (!found) g_string_sprintfa(gs, "<p><b>%s</b></p>\n", VTEXT(T_CALL_NOT_FOUND));
+        if (!found) g_string_append_printf(gs, "<p><b>%s</b></p>\n", VTEXT(T_CALL_NOT_FOUND));
     }
     g_string_append(gs, "<br><br><br>\n");
     html_footer(conn->response, HTML_CENTER);
