@@ -8,5 +8,8 @@
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
 #include "icons.inc"
 
