@@ -262,12 +262,12 @@ int sw_kst_mouse_func(struct subwin *sw, struct event *ev, int fw){
 			sw->callundery = ev->y;
 			gettimeofday(&tv, NULL);
 			ts = z_difftimeval_double(&tv, &sw->kst_latest_data);
-			if (ts < 1.0){
+			if (ts < 1.0 && ev->x < sw->w && sw->pattern == NULL){
 				// moved
 				g_free(sw->callunder);
 				sw->callunder = NULL;
 				zg_ptr_array_free_all(sw->callsunder);
-				sw->callsunder = sw_kst_calls_under(sw, sw->h, ev->y - sw->y);
+				sw->callsunder = sw_kst_calls_under(sw, Z_MIN(sw->h, 6), ev->y - sw->y);
 				struct menu_item *mi = new_menu(3);
 				mi->rtext = "Choose call";
 				int i;
@@ -275,7 +275,7 @@ int sw_kst_mouse_func(struct subwin *sw, struct event *ev, int fw){
 					char *c = (char*)g_ptr_array_index(sw->callsunder, i);
 					add_to_menu(&mi, g_strdup(c), "", "", sw_kst_call_choosen, GINT_TO_POINTER(i), 0);
 				}
-				set_window_ptr(gses->win, ev->x - 3, ev->y);
+				set_window_ptr(gses->win, ev->x - 8, ev->y - 3);
 				do_menu(mi, sw);
 			}
 			else{
@@ -284,7 +284,7 @@ int sw_kst_mouse_func(struct subwin *sw, struct event *ev, int fw){
 				sw->callunder = sw_kst_call_under(sw, ev->x - sw->x + sw->ho, ev->y - sw->y);
 
 				if (!sw->callunder) break;
-				kst_right_mouse_2(sw, sw->callunder);
+				kst_right_mouse_2(sw);
 			}
             break;
         case B_WHUP:
@@ -322,14 +322,16 @@ int sw_kst_mouse_func(struct subwin *sw, struct event *ev, int fw){
 void sw_kst_call_choosen(void *itdata, void *menudata){
 	struct subwin *sw = (struct subwin *)menudata;
 	char *call = (char *)g_ptr_array_index(sw->callsunder, GPOINTER_TO_INT(itdata));
-	kst_right_mouse_2(sw, call);
+	g_free(sw->callunder);
+	sw->callunder = g_strdup(call);
+	kst_right_mouse_2(sw);
 }
 
 
-void kst_right_mouse_2(struct subwin *sw, char *call){
+void kst_right_mouse_2(struct subwin *sw){
 	int items = 0;
 	struct menu_item *mi = new_menu(1);
-	mi->rtext = call;
+	mi->rtext = sw->callunder;
 	if (!cfg->usetouch){
 		add_to_menu(&mi, CTEXT(T_MISTAKE), "", CTEXT(T_HK_MISTAKE), sw_kst_nothing, NULL, 0); items++;
 	}
@@ -527,6 +529,8 @@ found:;
         if (aband && qrv_skip(qi, aband->bi, 1)) continue;
         if (kst_user_skip(sw, qi->call)) continue;
         if (kst_qrb_skip(qi, qi->call)) continue;
+		if (kst_wkdwwl_skip(qi)) continue;
+
         if (ofs) {
             ofs--;
             continue;
@@ -842,7 +846,8 @@ char *sw_kst_call_under(struct subwin *sw, int x, int y){
             if (aband != NULL && qrv_skip(qi, aband->bi, 0)) continue;
             if (kst_user_skip(sw, qi->call)) continue;
             if (kst_qrb_skip(qi, qi->call)) continue;
-            if (ofs) {
+			if (kst_wkdwwl_skip(qi)) continue;
+			if (ofs) {
                 ofs--;
                 continue;
             }
@@ -971,7 +976,7 @@ void sw_kst_toggle_highlight(struct subwin *sw_unused, char *call, int val){
             }
             if (val >= 0){
                 wwl = find_wwl_by_call(cw, t);
-                if (wwl != NULL) qrv_kst_add(t, wwl);
+                if (wwl != NULL) qrv_kst_add(t, wwl, NULL);
             }
         }
         //dbg("call='%s' inserted\n", t);
@@ -1237,7 +1242,7 @@ int sw_kst_color(char *call){
 int kst_read_line(struct subwin *sw, char *line){
     char *call, *mycall;
     int dummy;
-    char *c1 = NULL, *c2 = NULL, *c3 = NULL, *c4 = NULL, *wwl, *name;
+	char *c1 = NULL, *c2 = NULL, *c3 = NULL, *c4 = NULL, *c5 = NULL, *wwl, *name, *fullname;
     int ret = 0;
     struct qrv_item *qi;
 
@@ -1249,7 +1254,7 @@ int kst_read_line(struct subwin *sw, char *line){
 		}
     }
 
-    if (regmatch(line,"^([A-Z0-9\\(\\)\\/\\ -]{14})\\ ([A-R]{2}[0-9]{2}[A-X]{2})\\ ([^\\ ]{1,})", &c1, &c2, &c3, &c4, NULL)==0){
+    if (regmatch(line,"^([A-Z0-9\\(\\)\\/\\ -]{14})\\ ([A-R]{2}[0-9]{2}[A-X]{2})\\ (([^\\ ]{1,}).*)", &c1, &c2, &c3, &c4, &c5, NULL)==0){
         time_t now;
         struct tm gmt;
         int stamp;
@@ -1264,7 +1269,8 @@ int kst_read_line(struct subwin *sw, char *line){
         wwl = c3;
         z_str_uc(wwl);
         
-        name = c4;
+		fullname = c4;
+        name = c5;
         name[0] = z_char_uc(name[0]);
         z_strip_from(name, '/');
 
@@ -1279,7 +1285,7 @@ int kst_read_line(struct subwin *sw, char *line){
         qrbqtf(ctest ? ctest->pwwlo : cfg->pwwlo, wwl, &qrb, &qtf, NULL, 0);
         //if (cfg->kst_maxqrb > 0 && qrb >= cfg->kst_minqrb && qrb <= cfg->kst_maxqrb)
         {
-            qrv_kst_add(call, wwl);
+            qrv_kst_add(call, wwl, fullname);
         }
 
         if (sw->shus){
@@ -1291,7 +1297,7 @@ int kst_read_line(struct subwin *sw, char *line){
             if (sw->shus == 1) ret = 1; // skip
         }
     }
-    zg_free0(c1); zg_free0(c2); zg_free0(c3); zg_free0(c4);
+	zg_free0(c1); zg_free0(c2); zg_free0(c3); zg_free0(c4);	zg_free0(c5);
 
     if (regmatch(line, "^The\\ ([A-Z0-9]{1,})\\ locator\\ is\\ ([A-R]{2}[0-9]{2}[A-Z]{2})", &c1, &c2, &c3, NULL) == 0){
         time_t now;
@@ -1411,6 +1417,19 @@ int kst_qrb_skip(struct qrv_item *qi, char *call){
     return 1;
 }
 
+int kst_wkdwwl_skip(struct qrv_item *qi){
+	if (!aband) return 0;
+	if (ctest->wwlused == 0) return 0;
+	if (ctest->wwlmult == 0 && ctest->wwlbonu == 0) return 0;
+
+	char buf[5];
+	get_wwl(buf, qi->wwl);
+	if (g_hash_table_lookup(aband->stats->wwls, buf)){
+		return 1;
+	}
+	return 0;
+}
+
 void sw_kst_raise(struct subwin *sw){
     sw_qrv_sort(qrv);
 }
@@ -1565,20 +1584,20 @@ GPtrArray* sw_kst_calls_under(struct subwin *sw, int n, int y){
 	int index = sw->lines->len - sw->offset - sw->h + y;
 	if (index >= sw->lines->len) index = sw->lines->len - 1;
 
-	for (; index >= 0 && n > 0; index--, n--){
+	for (; index >= 0; index--){
 
 		char *b, *e;
-		dbg("i=%d\n", index);
+		//dbg("index=%d\n", index);
 		char *orig = (char *)g_ptr_array_index(sw->lines, index);
-		char *line = z_str_uc(g_strdup(orig));
+		char *line = z_str_uc(g_strconcat(orig, " ", NULL));
 		b = line;
 		while (*b != '\0'){
-			for (; *b != '\0' && !z_can_be_call_char(*b, ZCBC_MINUS); b++);
+			for (; *b != '\0' && !z_can_be_call_char(*b, ZCBC_MINUS); b++) {}
 			if (*b != '\0')
 			{
-				for (e = b; *e != '\0' && z_can_be_call_char(*e, ZCBC_MINUS); e++);
+				for (e = b; *e != '\0' && z_can_be_call_char(*e, ZCBC_MINUS); e++) {};
 				//if (*e == '\0') break; // while
-
+								   
 				*e = '\0';
 				if (regcmp(b, "^([0-9A-Z]{1,3}\\/)?([0-9][A-Z]|[A-Z]{1,2}[0-9]?)[0-9]{1,4}[A-Z]{1,4}(\\/[A-Z0-9]{1,3})*(-[0-9]{1,2})*$") == 0){
 				//if (z_can_be_call(b, ZCBC_MINUS)){
@@ -1586,12 +1605,17 @@ GPtrArray* sw_kst_calls_under(struct subwin *sw, int n, int y){
 					int eq = zg_ptr_array_find_str(ret, b);
 					if (eq == 1){
 						g_ptr_array_add(ret, g_strdup(b));
+						if (ret->len >= n) {
+							index = -1;
+							goto x;
+						}
 						dbg("%s\n", b);
 					}
 				}
 				b = e + 1;
 			}
 		}
+	x:;
 		g_free(line);
 
 	}
