@@ -55,6 +55,7 @@ void kst_end_shus(struct subwin *sw);
 void kst_clear_users(struct subwin *sw);
 int kst_user_skip(struct subwin *sw, const char *call);
 int kst_qrb_skip(struct qrv_item *qi, char *call);
+int kst_wkdwwl_skip(struct qrv_item *qi);
 void kst_shus(struct subwin *sw, int shus);
 void sw_kst_raise(struct subwin *sw);
 
@@ -67,7 +68,7 @@ void kst_free_screen(struct subwin *sw);
 void kst_open_bh(void *sw);
 void kst_dump_skip(void *x, void *menudata);
 GPtrArray* sw_kst_calls_under(struct subwin *sw, int n, int y);
-void kst_right_mouse_2(struct subwin *sw, char *call);
+void kst_right_mouse_2(struct subwin *sw);
 void sw_kst_call_choosen(void *itdata, void *menudata);
 
 
