@@ -28,7 +28,11 @@ struct translation_desc {
 
 char dummyarray[T__N_TEXTS];
 
+#ifdef Z_ANDROID
+#include "langascii.inc"
+#else
 #include "language.inc"
+#endif
 
 static char **translation_array[N_LANGUAGES][N_CODEPAGES];
 
@@ -65,12 +69,13 @@ void shutdown_trans(void)
 char *get_text_translation(char *text)
 {
     char **current_tra;
-    char *trn;
+    char *trn = NULL;
 
-   // dbg("get_text_translation('%s') spec=%p\n", text, term->spec);
+    //dbg("get_text_translation('%s') spec=%p\n", text, term->spec);
     //dbg("get_text_translation('%s') charset=%d\n", text, term->spec->charset);
 
     if (text < dummyarray || text > dummyarray + T__N_TEXTS) return text;
+    //dbg("--------get_text_translation(%d)\n", text - dummyarray);
     if ((current_tra = translation_array[current_language][term->spec->charset])) {
         if ((trn = current_tra[text - dummyarray])) return trn;
         tr:
@@ -87,7 +92,9 @@ char *get_text_translation(char *text)
             trn = translations[current_language].t[text - dummyarray].name = translation_english[text - dummyarray].name;   /* modifying translation structure */
         }
     }
-    //dbg("return '%s'\n", trn);
+        //dbg("trn=%p\n", trn);
+        //dbg("trn='%s'", trn);
+        //dbg("return\n");
     return trn;
 }
 
