@@ -276,6 +276,7 @@ static int ac;
 static char **av;
 int first_contest_def = 0;
 char *tucnak_dir = NULL;
+char *logs_dir = NULL;
 char *home_dir = NULL;
 
 static void init_home(void)
@@ -628,6 +629,10 @@ static void init(void)
 #ifdef Z_ANDROID
     SDL_Android_key_trace(android_trace_keys);
 #endif
+	
+	set_logs_dir();
+
+	z_wokna(logs_dir);
     	
 #ifdef Z_HAVE_SDL    
     sdl=init_sdl();
@@ -848,6 +853,7 @@ static void terminate_all_subsystems(void)
     //free_zptrarray();
     free_debug();
 	g_free(tucnak_dir);
+	g_free(logs_dir);
 	g_free(home_dir);
 }
 
@@ -1185,3 +1191,12 @@ void sigchld(void *arg, siginfo_t *siginfo, void *ctx)
 
 #endif
 
+void set_logs_dir(){
+	g_free(logs_dir);
+
+	if (cfg->logdirpath && *cfg->logdirpath)
+		logs_dir = g_strdup_printf("%s/%s", tucnak_dir, cfg->logdirpath);
+	else
+		logs_dir = g_strdup(tucnak_dir);
+}
+
