@@ -409,6 +409,18 @@ void sw_map_redraw_rain(struct subwin *sw, SDL_Rect *aarea, int flags){
 		if (grain->chmi != NULL) plot_rain_provider(sw, aarea, grain->chmi, ci);
 		if (grain->debug) break; 
 	} 
+
+	int i, px1, px2, py1, py2;
+	for (i = 0; i < grain->scps->len; i++){
+		struct rain_scp *scp = (struct rain_scp *)g_ptr_array_index(grain->scps, i);
+
+		km2px_d(sw, scp->kx, scp->ky, &px1, &py1);
+		km2px_d(sw, scp->kx + grain->minscpdist, scp->ky, &px2, &py2);
+		int r = (int)sqrt((px1 - px2)*(px1 - px2) + (py1 - py2)*(py1 - py2));
+		int c = scp->qrb <= grain->maxqrb ? sdl->gr[15] : sdl->gr[5];
+		z_circle(sw->screen, px1, py1, r, c);
+		if (r > 3) z_circle(sw->screen, px1, py1, r - 2, c);
+	}
 }
 
 void plot_rain_provider(struct subwin *sw, SDL_Rect *aarea, struct rain_provider *provider, int ci)
@@ -535,6 +547,7 @@ void plot_rain_provider(struct subwin *sw, SDL_Rect *aarea, struct rain_provider
 			}
 		}
 	}
+
 }
 
 void plot_rain_title(SDL_Surface *surface, SDL_Rect *area, int flags, struct rain_provider *provider, int *y){
@@ -1181,11 +1194,12 @@ x:;
 void map_recalc_cors(){
     int i;
     struct subwin *sw;
+	char *wwl = ctest ? ctest->pwwlo : cfg->pwwlo;
     
     for (i=0;i<gses->subwins->len;i++){
         sw=(struct subwin *)g_ptr_array_index(gses->subwins, i);
         if (sw->type!=SWT_MAP) continue;
-        zcors_recalc(sw->myh, sw->myw, ctest->pwwlo, zsel, map_cor_callback, cor_tucnakcor, COR_ITEMS);
+        zcors_recalc(sw->myh, sw->myw, wwl, zsel, map_cor_callback, cor_tucnakcor, COR_ITEMS);
         break; /* more maps with different pwwlo. but why? */
     }
 } 
