@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -15,6 +15,7 @@
 #include "charsets.h"
 #include "chart.h"
 #include "control.h"
+#include "cordata.h"
 #include "cwdaemon.h"
 #include "cwdb.h"
 #include "dwdb.h"
@@ -25,6 +26,7 @@
 #include "html.h"
 #include "inputln.h"
 #include "kst.h"
+#include "map.h"
 #include "main.h"
 #include "masterdb.h"
 #include "menu.h"
@@ -32,6 +34,7 @@
 #include "net.h"
 #include "qrvdb.h"
 #include "qsodb.h"
+#include "rain.h"
 #include "rotar.h"
 #include "tsdl.h"
 #include "session.h"
@@ -45,6 +48,9 @@
 #include "update.h"
 #include "vhfcontestnet.h"
 #include "slovhfnet.h"
+#include "sota.h"
+#include "sota_spot.h"
+#include "sota_upload.h"
 #ifdef VOIP
 #include "voip.h"
 #endif
@@ -122,7 +128,7 @@ static int select_dir_func(const char *dir, const struct dirent *de){
     if (strcmp((char *)de->d_name, "00000000")==0) return 0;
     r = regcmp((char *)de->d_name, "^[0-9]{8}(\\.[0-9]+)?$");
     if (r) return 0;
-    f = g_strconcat(tucnak_dir, "/", de->d_name, NULL);
+    f = g_strconcat(logs_dir, "/", de->d_name, NULL);
     if (stat(f, &st)) {
         g_free(f);
         return 0;
@@ -188,7 +194,7 @@ void contest_choose(void (*funcall)(struct menu *menu))
 
     free_namelist();
 
-    dir = g_strdup(tucnak_dir);
+	dir = g_strdup(logs_dir);
 
     n = z_scandir(dir, &namelist, select_dir_func, compare_dir_func);
     if (n<=0){
@@ -279,6 +285,17 @@ static void really_close_ctest(void)
     rel_write_all("CL\n");
     save_all_bands_txt(0);
     free_ctest();
+
+	update_hw();
+	qrv_recalc_qrbqtf(qrv);
+	qrv_recalc_gst(qrv);
+#ifdef Z_HAVE_SDL
+	map_recalc_cors();
+	maps_reload();
+	maps_update_showwwls();
+#endif   
+	chart_reload();
+	rain_reload();
 }
 
 void menu_save_all(void *arg){
@@ -297,6 +314,14 @@ void menu_export_cbr(void *arg){
     export_all_bands_cbr();
 }
 
+void menu_export_stf(void *arg){
+    export_all_bands_stf();
+}
+
+void menu_export_sota(void *arg){
+    export_all_bands_sota();
+}
+
 void menu_export_report(void *arg){
     export_all_bands_report();
 }
@@ -317,6 +342,33 @@ void menu_export_wiki(void *arg){
     export_all_bands_wiki();
 }
 
+void menu_sota_upload(void *arg){
+    sota_upload();
+}
+
+void menu_send_sota_spot(void *arg){
+    sota_spot_push();
+
+//    static char qrgstr[256];
+//    struct sota_spot_data ssd;
+//
+//    if (!ctest)
+//    {
+//        log_addf("No active contest");
+//        return;
+//    }
+
+//	//int rignr = GPOINTER_TO_INT(itdata);
+//    
+//    //g_snprintf(qrgstr, EQSO_LEN, "%1.0f", gtrigs->qrg);
+//	z_qrg_format(qrgstr, sizeof(qrgstr), gtrigs->qrg); 
+//
+//    input_field(NULL, CTEXT(T_FIXQRG), CTEXT(T_ENTER_QRG) ,
+//               CTEXT(T_OK), CTEXT(T_CANCEL), itdata, 
+//               NULL, 20, qrgstr, 0, 0, NULL,
+//               /*(void (*)(void *, char *))*/ fixqrg, NULL, 0);
+
+}
 
 void menu_import_edi(void *arg){
     char *pwd;
@@ -888,6 +940,30 @@ void subwins_menu(void *arg)
 }
 
 
+static char phase_str[EQSO_LEN];
+
+void menu_confirm_phase(void *xxx, char *phase){
+	int ph = atoi(phase);
+	if (ph >= 1) ctest->phase = ph;
+	save_all_bands_txt(0);
+	
+	char s[100];
+	g_snprintf(s, 100, "PH %d\n", ph);
+	rel_write_all(s);
+}
+
+
+void menu_phase(){
+	g_snprintf(phase_str, EQSO_LEN, "%d", ctest->phase);
+	input_field(NULL, VTEXT(T_PHASE), VTEXT(T_ENTER_PHASE),
+		VTEXT(T_OK), VTEXT(T_CANCEL), gses,
+		NULL, EQSO_LEN, phase_str, 1, 9, NULL,
+		menu_confirm_phase, NULL, 0);
+}
+
+
+
+
 /****************** NETWORK ********************************************/
 
 void display_codepage(void *arg)
@@ -1146,8 +1222,13 @@ static struct menu_item ctest_menu2[] = {
     {CTEXT(T_EXPORT_STATS),   "",  CTEXT(T_HK_EXPORT_STATS), MENU_FUNC menu_export_stats, NULL, 0 , 0},
     {CTEXT(T_EXPORT_TITLPAGE),"",  CTEXT(T_HK_EXPORT_TITLPAGE), MENU_FUNC menu_export_titlpage, NULL, 0 , 0},
     {CTEXT(T_EXPORT_CBR),     "",  CTEXT(T_HK_EXPORT_CBR), MENU_FUNC menu_export_cbr, NULL, 0, 0},
+    {CTEXT(T_EXPORT_STF),     "",  CTEXT(T_HK_EXPORT_STF), MENU_FUNC menu_export_stf, NULL, 0, 0},
+    {CTEXT(T_EXPORT_SOTA),     "",  CTEXT(T_HK_EXPORT_SOTA), MENU_FUNC menu_export_sota, NULL, 0, 0},
     {CTEXT(T_EXPORT_WIKI),    "",  CTEXT(T_HK_EXPORT_WIKI), MENU_FUNC menu_export_wiki, NULL, 0, 0},
 	{CTEXT(T_MEDIAWIKI_UPLOAD), "", CTEXT(T_HK_MEDIAWIKI_UPLOAD), MENU_FUNC wiki_upload, NULL, 0, 0},
+    {CTEXT(T_SOTA_UPLOAD_LOG),     "",  CTEXT(T_HK_SOTA_UPLOAD_LOG), MENU_FUNC menu_sota_upload, NULL, 0, 0},
+    {"", "", M_BAR, NULL, NULL, 0, 0},
+    {CTEXT(T_SEND_SOTA_SPOT),     "",  CTEXT(T_HK_SEND_SOTA_SPOT), MENU_FUNC menu_send_sota_spot, NULL, 0, 0},
     {"", "", M_BAR, NULL, NULL, 0, 0},
     {CTEXT(T_IMPORT_EDI),     "",  CTEXT(T_HK_IMPORT_EDI),  MENU_FUNC menu_import_edi,  NULL, 0, 0},
     {CTEXT(T_IMPORT_ADIF),    "",  CTEXT(T_HK_IMPORT_ADIF), MENU_FUNC menu_import_adif, NULL, 0, 0},
@@ -1169,7 +1250,8 @@ void do_contest_menu(void *arg)
 
 static struct menu_item edit_menu[] = {
     {CTEXT(T_RUN_MODE), "", CTEXT(T_HK_RUN_MODE), MENU_FUNC menu_runmode, NULL, 0, 0},
-    {CTEXT(T_SP_MODE), "", CTEXT(T_HK_SP_MODE), MENU_FUNC menu_spmode, NULL, 0, 0},
+	{CTEXT(T_SP_MODE), "", CTEXT(T_HK_SP_MODE), MENU_FUNC menu_spmode, NULL, 0, 0},
+	{CTEXT(T_PHASE), "", CTEXT(T_HK_PHASE), MENU_FUNC menu_phase, NULL, 0, 0},
     {"", "", M_BAR, NULL, NULL, 0, 0},
     {CTEXT(T_1ST), "", CTEXT(T_HK_1ST), MENU_FUNC menu_extcq, GINT_TO_POINTER(EC_1ST), 0, 0},
     {CTEXT(T_2ND), "", CTEXT(T_HK_2ND), MENU_FUNC menu_extcq, GINT_TO_POINTER(EC_2ND), 0, 0},
