@@ -23,6 +23,7 @@
 #include "net.h"
 #include "qrvdb.h"
 #include "qsodb.h"
+#include "rain.h"
 #include "rc.h"
 #include "stats.h"
 #include "terminal.h"
@@ -52,7 +53,7 @@ char default_rst[MAX_STR_LEN],default_rs[MAX_STR_LEN];
 static char operator_[EQSO_LEN];
 int tttype;
 char tttype_str[MAX_STR_LEN];
-int expmode;
+int expmode, phase;
 
 char new_excname[MAX_STR_LEN], old_excname[MAX_STR_LEN];
 /*int qsop_method=1, total_method=1;*/
@@ -661,7 +662,7 @@ void menu_responsible_op(void *arg){
 
 /******************** QSOP METHOD, TOTAL METHOD  ******************/
 
-#define MAX_QSOP_METHOD 21
+#define MAX_QSOP_METHOD 22
 #define MAX_TOTAL_METHOD 4
 
 int qsop_method=1, total_method=1;
@@ -689,7 +690,8 @@ char *qsop_method_msg[]={
     CTEXT(T_QP18),
     CTEXT(T_QP19),
     CTEXT(T_QP20),
-    CTEXT(T_QP21),
+	CTEXT(T_QP21),
+	CTEXT(T_QP22),
 };
 
 char *total_method_msg[]={
@@ -936,6 +938,7 @@ void wizz_func (void *arg){
     tttype=wi->tttype;
     safe_strncpy0(tttype_str, get_text_translation(tttype_msg[tttype]), MAX_STR_LEN);
     expmode=0;
+	phase = 1;
 
     
     qsop_method=wi->qsop_method;
@@ -1096,6 +1099,7 @@ void init_ctest2(int from_dlg, int updloc, struct zstring *zs2, struct wizz_item
         STORE_INT (ctest,rstused);
         STORE_ENUM (ctest,tttype, enum tttype);
         STORE_INT (ctest,expmode);
+		STORE_INT(ctest, phase);
         STORE_INT (ctest,defrstr);
         STORE_INT (ctest,qsop_method);
         STORE_INT (ctest,total_method);
@@ -1140,7 +1144,8 @@ void init_ctest2(int from_dlg, int updloc, struct zstring *zs2, struct wizz_item
 			maps_update_showwwls();
 #endif   
             chart_reload();
-            //qrv_recalc_wkd(qrvdb); probably not needed
+			rain_reload();
+			//qrv_recalc_wkd(qrvdb); probably not needed
         }
         save_all_bands_txt(0);
         return;
@@ -1311,20 +1316,67 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     d->items[i].msg = CTEXT(T_DATE_OF_CTEST);
     d->items[i].wrap = 1;
     
+	d->items[++i].type = D_CHECKBOX;
+	d->items[i].gid = 0;
+	d->items[i].gnum = 1;
+	d->items[i].dlen = sizeof(int);
+	d->items[i].data = (char *)&expmode;
+	d->items[i].msg = CTEXT(T_EXPMODE);
+	d->items[i].wrap = 2;
+
+
+
+	d->items[++i].type = D_TEXT;
+	d->items[i].msg = TRANSLATE("    Band options:");
+	d->items[i].wrap = 1;
+
+	firstbandbutt = i + 1;
+	/*    dbg("firstband=%d\n",i+1);*/
+	if (!from_ctest){
+		for (j = 0; j<26; j++){
+			struct config_band *confb;
+
+			if (j >= cfg->bands->len) break; /* no config file */
+
+			confb = (struct config_band*)g_ptr_array_index(cfg->bands, j);
+			if (!confb) break;  /* unreached? */
+			if (!confb->qrvnow) continue;
+
+			d->items[++i].type = D_BUTTON;
+			d->items[i].gid = 0;
+			d->items[i].fn = dlg_band_settings_confb;
+			d->items[i].text = confb->pband;
+		}
+	}
+	else{
+		for (j = 0; j<ctest->bands->len; j++){
+			struct band *band;
+
+			band = (struct band*)g_ptr_array_index(ctest->bands, j);
+			if (!band) break;  /* unreached? */
+
+			d->items[++i].type = D_BUTTON;
+			d->items[i].gid = 0;
+			d->items[i].fn = dlg_band_settings;
+			d->items[i].text = band->pband;
+		}
+	}
+	/*    dbg("lastband=%d\n",i);*/
+	d->items[i].wrap = 2;
+
+
+
+
+	d->items[++i].type = D_TEXT;
+	d->items[i].msg = TRANSLATE("    Advanced options:");
+	d->items[i].wrap = 1;
+
     d->items[++i].type = D_BUTTON;     
     d->items[i].gid  = 0;
     d->items[i].fn   = dlg_tttype;
     d->items[i].text = tttype_str;
     d->items[i].msg = CTEXT(T_TTTYPE);
     
-    d->items[++i].type = D_CHECKBOX;  
-    d->items[i].gid = 0;
-    d->items[i].gnum = 1;
-    d->items[i].dlen = sizeof(int);
-    d->items[i].data=(char *)&expmode;
-    d->items[i].msg = CTEXT(T_EXPMODE);
-    d->items[i].wrap = 1;
-
     
     d->items[++i].type = D_CHECKBOX3;  
     d->items[i].gid = 0;
@@ -1460,7 +1512,7 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     d->items[i].gnum = 999999;
     d->items[i].msg = CTEXT(T_DXCB);
     
-    d->items[++i].type = D_FIELD;        /* 20 */
+    d->items[++i].type = D_FIELD;        
     d->items[i].data = dxcmult_str;
     d->items[i].dlen = 8;
     d->items[i].maxl = 3;
@@ -1503,12 +1555,13 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     d->items[i].msg = CTEXT(T_ALSORSTR);
     d->items[i].wrap = 1;
     
-    d->items[++i].type = D_BUTTON;          /* 25 */
+    d->items[++i].type = D_BUTTON;          
     d->items[i].gid  = 0;
     d->items[i].fn   = dlg_qsop_method;
     d->items[i].text = qsop_method_str;
     d->items[i].msg = CTEXT(T_QP_CALC);
-    
+	d->items[i].wrap = 1;
+
     d->items[++i].type = D_BUTTON;     
     d->items[i].gid  = 0;
     d->items[i].fn   = dlg_total_method;
@@ -1516,41 +1569,9 @@ void contest_options1(char *title, int from_ctest, struct wizz_item *wi)
     d->items[i].msg = CTEXT(T_TO_CALC);
     d->items[i].wrap = 2;
 
-     
-    firstbandbutt=i+1;
-    /*    dbg("firstband=%d\n",i+1);*/
-    if (!from_ctest){
-        for (j=0;j<26;j++){
-            struct config_band *confb;
 
-            if (j>=cfg->bands->len) break; /* no config file */
-            
-            confb = (struct config_band*)g_ptr_array_index(cfg->bands,j);
-            if (!confb) break;  /* unreached? */
-            if (!confb->qrvnow) continue;
-            
-            d->items[++i].type = D_BUTTON;
-            d->items[i].gid  = 0;
-            d->items[i].fn   = dlg_band_settings_confb; 
-            d->items[i].text = confb->pband;
-        }
-    }else{
-        for (j=0;j<ctest->bands->len;j++){
-            struct band *band;
 
-            band = (struct band*)g_ptr_array_index(ctest->bands,j);
-            if (!band) break;  /* unreached? */
-            
-            d->items[++i].type = D_BUTTON;
-            d->items[i].gid  = 0;
-            d->items[i].fn   = dlg_band_settings;
-            d->items[i].text = band->pband;
-        }
-    }
-/*    dbg("lastband=%d\n",i);*/
-    d->items[i].wrap = 2;
-    
-    d->items[++i].type = D_BUTTON;
+	d->items[++i].type = D_BUTTON;
     d->items[i].gid = B_ENTER;
     d->items[i].fn = ok_dialog;
     d->items[i].text = VTEXT(T_OK);
@@ -1626,7 +1647,7 @@ void contest_options1_from_menu(void *arg)
     tttype=TT_RSTS;
     safe_strncpy0(tttype_str, get_text_translation(tttype_msg[tttype]), MAX_STR_LEN);
     expmode=0;
-   
+	phase = 1;
     contest_options1(VTEXT(T_NEW_CTEST), 0, NULL);
 }
                                
@@ -1674,7 +1695,7 @@ void contest_options1_from_ctest(void *arg)
     tttype=ctest->tttype;
     safe_strncpy0(tttype_str,get_text_translation(tttype_msg[tttype]),MAX_STR_LEN);
     expmode=ctest->expmode;
-    
+	phase = ctest->phase;
     contest_options1(VTEXT(T_CONTEST_OP), 1, NULL);
 }
                                
@@ -1691,6 +1712,7 @@ int global_operator;
 char dxc_host[MAX_STR_LEN], dxc_port_str[EQSO_LEN];
 char dxc_user[MAX_STR_LEN], dxc_pass[MAX_STR_LEN];
 char kst_user[MAX_STR_LEN], kst_pass[MAX_STR_LEN], kst_name[MAX_STR_LEN], slovhf_user[MAX_STR_LEN];
+char sota_user[MAX_STR_LEN], sota_pass[MAX_STR_LEN];
 char contest_def_is_first = 0;
 
 void refresh_contest_def(void *xxx)
@@ -1716,6 +1738,8 @@ void refresh_contest_def(void *xxx)
 	STORE_STR(cfg, kst_user);
 	STORE_STR(cfg, kst_pass);
 	STORE_STR(cfg, kst_name);
+    STORE_STR(cfg, sota_user);
+    STORE_STR(cfg, sota_pass);
 	STORE_STR(cfg, slovhf_user);
 
 	if (contest_def_is_first){
@@ -1723,6 +1747,7 @@ void refresh_contest_def(void *xxx)
 		cfg->global_operator = 1;
 		g_free(cfg->dxc_user);  	cfg->dxc_user = g_strdup(pcall);	z_str_lc(cfg->dxc_user);
 		g_free(cfg->kst_user);		cfg->kst_user = g_strdup(pcall);	z_str_lc(cfg->kst_user);
+		g_free(cfg->sota_user);		cfg->sota_user = g_strdup(pcall);	z_str_lc(cfg->sota_user);
 	}
 
 
@@ -1731,6 +1756,7 @@ void refresh_contest_def(void *xxx)
 #ifdef Z_HAVE_SDL
     if (updloc) maps_reload();
 	maps_update_showwwls();
+	rain_reload();
 
 #endif
 	if (first_contest_def){
@@ -1812,6 +1838,8 @@ void contest_def(void *pfirst)
 	safe_strncpy0(kst_user, cfg->kst_user, MAX_STR_LEN);
 	safe_strncpy0(kst_pass, cfg->kst_pass, MAX_STR_LEN);
 	safe_strncpy0(kst_name, cfg->kst_name, MAX_STR_LEN);
+	safe_strncpy0(sota_user, cfg->sota_user, MAX_STR_LEN);
+	safe_strncpy0(sota_pass, cfg->sota_pass, MAX_STR_LEN);
 	safe_strncpy0(slovhf_user, cfg->slovhf_user, MAX_STR_LEN);
 
 
@@ -1964,6 +1992,19 @@ void contest_def(void *pfirst)
 		d->items[i].msg = CTEXT(T_PASSWORD);
 		d->items[i].wrap = 1;
 
+		d->items[++i].type = D_FIELD;
+		d->items[i].dlen = MAX_STR_LEN;
+		d->items[i].data = sota_user;
+		d->items[i].maxl = 14;
+		d->items[i].msg = CTEXT(T_SOTA_USERNAME);
+
+		d->items[++i].type = D_FIELD;
+		d->items[i].dlen = MAX_STR_LEN;
+		d->items[i].data = sota_pass;
+		d->items[i].maxl = 15;
+		d->items[i].msg = CTEXT(T_PASSWORD);
+		d->items[i].wrap = 1;
+
 		d->items[++i].type = D_FIELD;
 		d->items[i].dlen = MAX_STR_LEN;
 		d->items[i].data = kst_user;
