@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2006  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
 #include "net.h"
 #include "qrvdb.h"
 #include "qsodb.h"
+#include "rain.h"
 #include "session.h"
 #include "sked.h"
 #include "stats.h"
@@ -63,14 +64,14 @@ static char callsign[EQSO_LEN], rstr[EQSO_LEN], qsonrr[EQSO_LEN], exc[MAX_EXC_LE
 /*gint mode;
 char mode_str[EQSO_LEN]*/
 char rsts[EQSO_LEN], qsonrs[EQSO_LEN];
-static char date_str[EQSO_LEN], time_str[EQSO_LEN], operator_[EQSO_LEN], remark[MAX_STR_LEN]; 
+static char date_str[EQSO_LEN], time_str[EQSO_LEN], operator_[EQSO_LEN], remark[MAX_STR_LEN], phase_str[EQSO_LEN];
 gint qerror,qsl;
 
 #define OEQSO_LEN 24
 #define QRG_LEN 50
 char ocallsign[OEQSO_LEN], orstr[OEQSO_LEN], oqsonrr[OEQSO_LEN], oexc[MAX_EXC_LEN+1], olocator[OEQSO_LEN];
 char omode_str[OEQSO_LEN], orsts[OEQSO_LEN], oqsonrs[OEQSO_LEN];
-char odate_str[OEQSO_LEN], otime_str[OEQSO_LEN], ooperator[OEQSO_LEN], oremark[MAX_STR_LEN], oqrg[QRG_LEN]; 
+char odate_str[OEQSO_LEN], otime_str[OEQSO_LEN], ooperator[OEQSO_LEN], oremark[MAX_STR_LEN], oqrg[QRG_LEN], ophase_str[EQSO_LEN]; 
 
 char oomode_str[OEQSO_LEN], oorstr[OEQSO_LEN], oorsts[OEQSO_LEN];
 
@@ -132,6 +133,7 @@ void refresh_edit_qso(struct qso *q)
     STORE_STR_FS_UC(q,exc);
     STORE_STR_FS_UC(q,locator);
     STORE_STR_FS   (q,remark);
+	STORE_SINT     (q, phase);
     q->error = qerror;
     q->qsl   = qsl;
 
@@ -161,7 +163,8 @@ void refresh_edit_qso(struct qso *q)
 	maps_reload();
 #endif
     chart_reload();    
-    dump_qso(q, "refresh_edit_qso after");
+	rain_reload();
+	dump_qso(q, "refresh_edit_qso after");
     dump_all_sources(ctest);
 }                    
 
@@ -178,10 +181,11 @@ char *edit_qso_msg[] = {
     otime_str,
     ooperator, 
     oremark  , /* 10 */
+	ophase_str,
     /*oqrg, */
     CTEXT(T_ERROR),
     CTEXT(T_QSL),
-    "", /* OK */  /* 13 */
+    "", /* OK */  /* 14 */
     "", /* Cancel */
 };
 
@@ -219,9 +223,11 @@ void edit_qso_fn(struct dialog_data *dlg)
     min_group_width(term, edit_qso_msg +11 , dlg->items +11, 1, &min);
     max_group_width(term, edit_qso_msg +12 , dlg->items +12, 1, &max);
     min_group_width(term, edit_qso_msg +12 , dlg->items +12, 1, &min);
-    
-    max_buttons_width(term, dlg->items +13, 2, &max);
-    min_buttons_width(term, dlg->items +13, 2, &min);
+	max_group_width(term, edit_qso_msg + 13, dlg->items + 13, 1, &max);
+	min_group_width(term, edit_qso_msg + 13, dlg->items + 13, 1, &min);
+
+    max_buttons_width(term, dlg->items +14, 2, &max);
+    min_buttons_width(term, dlg->items +14, 2, &min);
     
     w = dlg->win->term->x * 9 / 10 - 2 * DIALOG_LB;
     if (w > max) w = max;
@@ -245,9 +251,10 @@ void edit_qso_fn(struct dialog_data *dlg)
     dlg_format_group(NULL, term, edit_qso_msg +10, dlg->items +10, 1, 0, &y, w, &rw);
     dlg_format_text (NULL, term, oqrg, dlg->x +6, &y, w, &rw, COLOR_DIALOG_TEXT, 0);
     dlg_format_group(NULL, term, edit_qso_msg +11, dlg->items +11, 1, 0, &y, w, &rw);
-    dlg_format_group(NULL, term, edit_qso_msg +12, dlg->items +12, 1, 0, &y, w, &rw);
+	dlg_format_group(NULL, term, edit_qso_msg + 12, dlg->items + 12, 1, 0, &y, w, &rw);
+	dlg_format_group(NULL, term, edit_qso_msg + 13, dlg->items + 13, 1, 0, &y, w, &rw);
     y++;
-    dlg_format_buttons(NULL, term, dlg->items +13, 2, 0, &y, w, &rw, AL_LEFT);
+	dlg_format_buttons(NULL, term, dlg->items + 14, 2, 0, &y, w, &rw, AL_LEFT);
     
     w = rw;
     dlg->xw = w + 2 * DIALOG_LB;
@@ -272,9 +279,10 @@ void edit_qso_fn(struct dialog_data *dlg)
     dlg_format_group(term, term, edit_qso_msg +10, dlg->items +10, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
     dlg_format_text (term, term, oqrg, dlg->x +6, &y, w, &rw, COLOR_DIALOG_TEXT, 0);
     dlg_format_group(term, term, edit_qso_msg +11, dlg->items +11, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
-    dlg_format_group(term, term, edit_qso_msg +12, dlg->items +12, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
+	dlg_format_group(term, term, edit_qso_msg + 12, dlg->items + 12, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
+	dlg_format_group(term, term, edit_qso_msg + 13, dlg->items + 13, 1, dlg->x + DIALOG_LB, &y, w, AL_LEFT);
     y++;
-    dlg_format_buttons(term, term, dlg->items +13, 2, dlg->x + DIALOG_LB, &y, w, NULL, AL_LEFT);
+    dlg_format_buttons(term, term, dlg->items +14, 2, dlg->x + DIALOG_LB, &y, w, NULL, AL_LEFT);
     
 }
 
@@ -303,7 +311,8 @@ void edit_qso(struct qso *qso)
     safe_strncpy0(date_str,  qso->date_str,  EQSO_LEN); 
     safe_strncpy0(time_str,  qso->time_str,  EQSO_LEN);
     safe_strncpy0(operator_, qso->operator_, EQSO_LEN);
-    safe_strncpy0(remark,    qso->remark,    MAX_STR_LEN);
+	safe_strncpy0(remark,    qso->remark,    MAX_STR_LEN);
+	LOAD_SINT(qso, phase);
     qerror = qso->error;
     qsl    = qso->qsl;
     
@@ -322,7 +331,8 @@ void edit_qso(struct qso *qso)
     g_snprintf(odate_str, OEQSO_LEN, "%s %-15s", VTEXT(T_DATE)     , date_str);
     g_snprintf(otime_str, OEQSO_LEN, "%s %-15s", VTEXT(T_TIME)     , time_str);
     g_snprintf(ooperator, OEQSO_LEN, "%s %-15s", VTEXT(T_OPERATOR) , operator_);
-    g_snprintf(oremark  , OEQSO_LEN, "%s %-15s", VTEXT(T_REMARK)   , remark  );
+	g_snprintf(oremark,   OEQSO_LEN, "%s %-15s", VTEXT(T_REMARK), remark);
+	g_snprintf(ophase_str,OEQSO_LEN, "%s %-15s", VTEXT(T_PHASE_E), phase_str);
     
     sprintf(s,"%0.0f", qso->qrg); 
     len=strlen(s);
@@ -395,7 +405,11 @@ void edit_qso(struct qso *qso)
     d->items[i].maxl = EQSO_LEN;
     d->items[i].data = remark;
    
-    d->items[++i].type = D_CHECKBOX;
+	d->items[++i].type = D_FIELD;   
+	d->items[i].dlen = EQSO_LEN;
+	d->items[i].data = phase_str;
+
+	d->items[++i].type = D_CHECKBOX;
     d->items[i].gid = 0;
     d->items[i].gnum = 1;
     d->items[i].dlen = sizeof(int);
@@ -407,12 +421,12 @@ void edit_qso(struct qso *qso)
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&qsl;
     
-    d->items[++i].type = D_BUTTON;      /* 13 */
+    d->items[++i].type = D_BUTTON;      /* 14 */
     d->items[i].gid = B_ENTER;
     d->items[i].fn = ok_dialog;
     d->items[i].text = VTEXT(T_OK);
     
-    d->items[++i].type = D_BUTTON;      /* 14 */
+    d->items[++i].type = D_BUTTON;      /* 15 */
     d->items[i].gid = B_ESC;
     d->items[i].fn = cancel_dialog;
     d->items[i].text = VTEXT(T_CANCEL);
