@@ -13,6 +13,7 @@
 #include "bfu.h"
 #include "fifo.h"
 #include "kbd.h"
+#include "main.h"
 #include "menu.h"
 #include "qsodb.h"
 #include "rc.h"
@@ -31,6 +32,14 @@ int fullscreen, usetouch, altsyms, nolocks, portrait, reverse, inverse;
 char fontheight_str[EQSO_LEN];
 char slashkey[3];
 int dssaver;
+int adif_export_mode_t2r;
+char adif_export_mode_t2r_str[EQSO_LEN];
+char *adif_export_modes[] = {
+    "Error",
+    "Call",
+    "Skip"
+};
+char logdirpath[MAX_STR_LEN];
 
 void refresh_misc_opts(void *xxx)
 {
@@ -67,6 +76,8 @@ void refresh_misc_opts(void *xxx)
     }
 
 	STORE_INT(cfg, inverse);
+	STORE_INT(cfg, adif_export_mode_t2r);
+	STORE_STR(cfg, logdirpath);
     
     new_w=800;
     new_h=600;
@@ -120,6 +131,25 @@ void refresh_misc_opts(void *xxx)
         if (resize) resize_terminal(NULL);
     }
 
+	set_logs_dir();
+
+}
+
+void set_adif_export_mode(void *arg, void *arg2){
+    adif_export_mode_t2r = GPOINTER_TO_INT(arg);
+    strcpy(adif_export_mode_t2r_str, adif_export_modes[adif_export_mode_t2r]);
+    redraw_later();
+}
+
+int choose_adif_export_mode(struct dialog_data *dlg, struct dialog_item_data *di){
+    struct menu_item *mi;
+    int i;
+
+    if (!(mi = new_menu(1))) return 0;
+
+    for (i = 0; i < 3; i++) add_to_menu(&mi, adif_export_modes[i], "", "", set_adif_export_mode, GINT_TO_POINTER(i), 0);
+    do_menu_selected(mi, di->cdata, adif_export_mode_t2r);
+    return 0;
 }
 
 void misc_opts(void *arg)
@@ -166,7 +196,8 @@ void misc_opts(void *arg)
 	portrait = cfg->portrait;
 	reverse = cfg->reverse;
 	inverse = cfg->inverse;
-
+	adif_export_mode_t2r = cfg->adif_export_mode_t2r;
+	LOAD_STR(cfg, logdirpath);
 
     d = g_new0(struct dialog, 20);
     d->title = VTEXT(T_MISCOPTS);
@@ -318,6 +349,21 @@ void misc_opts(void *arg)
 	d->items[i].msg = TRANSLATE("Inverse display");
 	d->items[i].wrap = 1;
 
+	strcpy(adif_export_mode_t2r_str, adif_export_modes[adif_export_mode_t2r]);
+	d->items[++i].type = D_BUTTON;
+	d->items[i].gid = 0;
+	d->items[i].fn = choose_adif_export_mode;
+	d->items[i].data=(char *)&adif_export_mode_t2r;
+	d->items[i].msg = CTEXT(T_ADIF_EXPORT_MODE);
+	d->items[i].text = adif_export_mode_t2r_str;
+	d->items[i].wrap = 1;
+
+	d->items[++i].type = D_FIELD;
+	d->items[i].dlen = MAX_STR_LEN;
+	d->items[i].data = logdirpath;
+	d->items[i].maxl = 15;
+	d->items[i].msg = CTEXT(T_LOGDIR_PATH);
+	d->items[i].wrap = 1;
 
 	d->items[i].wrap++;
     d->items[++i].type = D_BUTTON;   
