@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -173,7 +173,7 @@ static void format_one_name(gpointer key, gpointer value, gpointer user_data){
     call = (gchar *) key;
     name = (gchar *) value;
 
-    g_string_sprintfa(gs, "%s %s;", call, name);
+    g_string_append_printf(gs, "%s %s;", call, name);
 }
 
 int format_namedb_string(struct namedb *namedb, GString *gs){
