@@ -200,7 +200,6 @@ void parport_info(GString *gs){
     int port;
     int fd;
     char s[1024];
-    char errbuf[1024];
     unsigned int modes;
     int mode;
 
@@ -210,12 +209,16 @@ void parport_info(GString *gs){
         fd=open(s, O_RDWR|O_NONBLOCK);
         if (fd<0){
             if (errno==ENOENT) continue;
-            g_string_append_printf(gs, "Found /dev/parport%d but cannot open it: %s\n", port, strerror_r(errno, errbuf, sizeof(errbuf)));
+            char *c = z_strdup_strerror(errno);
+            g_string_append_printf(gs, "Found /dev/parport%d but cannot open it: %s\n", port, c);
+            g_free(c);
             continue;
         }
         if (ioctl(fd, PPGETMODES, &modes)<0){
             if (errno==ENODEV) continue;
-            g_string_append_printf(gs, "Can't get modes for /dev/parport%d: %s\n", port, strerror_r(errno, errbuf, sizeof(errbuf)));
+            char *c = z_strdup_strerror(errno);
+            g_string_append_printf(gs, "Can't get modes for /dev/parport%d: %s\n", port, c);
+            g_free(c);
             close(fd);
             continue;
         }
