@@ -178,25 +178,125 @@ struct qrv_item *qrv_add(gchar *call, gchar *wwl, int qrv_int, int wkd[32], cons
     return qi;
 }
 
-struct qrv_item *qrv_kst_add(char *call, char *wwl){
+#define QFL_BREAK 1
+
+struct qrvbandregex{
+	int qrv_int;
+	char *regstr;
+	int flags;
+	regex_t *reg; // never freed
+};
+
+#define QB(b)  (1 << (b - 'A'))
+
+struct qrvbandregex qrvbr[] = {
+	// !important
+	{ QB('C') | QB('E') | QB('G') | QB('H') | QB('I') | QB('J'), "\\<2m {0,}- {0,}6[^0-9]", QFL_BREAK },
+	{ QB('E') | QB('G') | QB('H') | QB('I') | QB('J'), "\\<70 {0,}- {0,}6[^0-9]", QFL_BREAK },
+	{ QB('E') | QB('G') | QB('H') | QB('I') | QB('J') | QB('K'), "\\<23 {0,}- {0,}3[^0-9]", QFL_BREAK },
+	{ QB('G') | QB('H') | QB('I') | QB('J') | QB('K'), "\\<23 {0,}- {0,}3[^0-9]", QFL_BREAK },
+	{ QB('G') | QB('H') | QB('I'), "\\<23 {0,}- {0,}9[^0-9]", QFL_BREAK },
+
+	// normal
+	{ QB('A'), "\\<6m[^0-9]" },
+	{ QB('B'), "\\<4[^0-9]" },
+	{ QB('B'), "\\<70m[^0-9]" },
+
+	{ QB('C'), "\\<2[^0-9]" },
+	{ QB('C'), "\\<144[^0-9]" },
+	{ QB('C'), "\\<144mhz\\>" },
+
+	{ QB('E'), "\\<70[^0-9]" },
+	{ QB('E'), "\\<432[^0-9]" },
+	{ QB('E'), "\\<432mhz\\>" },
+	{ QB('E'), "\\<433[^0-9]" },
+	{ QB('E'), "\\<433mhz\\>" },
+
+	{ QB('G'), "\\<23[^0-9]" },
+	{ QB('G'), "\\<23cm\\>" },
+	{ QB('G'), "\\<1296[^0-9]" },
+	{ QB('G'), "\\<1\\.2[^0-9]" },
+	{ QB('G'), "\\<1\\.3[^0-9]" },
+
+	{ QB('H'), "\\<13[^0-9]" },
+	{ QB('H'), "\\<2\\.3[^0-9]" },
+	{ QB('H'), "\\<2320[^0-9]" },
+
+	{ QB('I'), "\\<9[^0-9]" },
+	{ QB('I'), "\\<3\\.4[^0-9]" },
+	{ QB('I'), "\\<3,4[^0-9]" },
+
+	{ QB('J'), "\\<6[^0-9]" },
+	{ QB('J'), "\\<5\\.6[^0-9]" },
+	{ QB('J'), "\\<5,6[^0-9]" },
+	{ QB('J'), "\\<5\\.7[^0-9]" },
+	{ QB('J'), "\\<5,7[^0-9]" },
+	{ QB('J'), "\\<5760[^0-9]" },
+
+	{ QB('K'), "\\<3[^0-9]" },
+	{ QB('K'), "\\<10368[^0-9]" },
+
+	{ QB('L'), "\\<1\\.2[^0-9]" },
+	{ QB('L'), "\\<24[^0-9]" },
+
+	{ QB('M'), "\\<47[^0-9]" },
+
+	{ QB('N'), "\\<76[^0-9]" },
+
+	{ QB('O'), "\\<122[^0-9]" },
+
+	{ QB('P'), "\\<134[^0-9]" },
+
+	{ QB('Q'), "\\<248[^0-9]" },
+
+
+	{ -1, NULL }
+};
+
+struct qrv_item *qrv_kst_add(char *call, char *wwl, char *fullname){
 	int i, qrv_int = 0, wkd[32];
 	struct qrv_item *ret;
 
 	memset(wkd, 0, sizeof(wkd));
 
-	if (ctest != NULL){
-		for (i = 0; i < ctest->bands->len; i++){
-			struct band *b = (struct band *)g_ptr_array_index(ctest->bands, i);
-			if (b->readonly == 0) qrv_int |= (1 << b->bi);
+	if (0 && fullname != NULL){ // QRV from full name (Dan 23/13/6/3/24)
+		struct qrvbandregex *reg;
+		for (reg = qrvbr; reg->regstr != NULL; reg++){
+			if (reg->reg == NULL){
+				reg->reg = g_new(regex_t, 1);
+				i= regcomp(reg->reg, reg->regstr, REG_EXTENDED | REG_NOSUB | REG_ICASE);
+				if (i) zinternal("regcomp failed for %s", reg->regstr);
+			}
+			int match = regexec(reg->reg, fullname, 0, 0, 0);
+			if (match == 0) {
+				qrv_int |= reg->qrv_int;
+				if (reg->flags & QFL_BREAK) break;
+			}
 		}
-	}
-	else{
-		for (i = 0; i < cfg->bands->len; i++){
-			int bi;
-			struct config_band *cb = (struct config_band *)g_ptr_array_index(cfg->bands, i);
-			if (cb->qrvnow == 0) continue;
-			bi = toupper(cb->bandchar) - 'A';
-			qrv_int |= (1 << bi);
+#if 1
+		dbg("%s    ", fullname);
+		for (i = 0; i < 32; i++)
+		{
+			if (qrv_int & (1 << i)) dbg("%c", 'A' + i);
+		}
+		dbg("\n");
+#endif
+	}else{ // QRV from QRV bands
+//fromqrv:;
+		if (ctest != NULL){
+			for (i = 0; i < ctest->bands->len; i++){
+				struct band *b = (struct band *)g_ptr_array_index(ctest->bands, i);
+				if (b->readonly == 0) qrv_int |= (1 << b->bi);
+			}
+		}
+		else{
+			for (i = 0; i < cfg->bands->len; i++){
+				int bi;
+				struct config_band *cb = (struct config_band *)g_ptr_array_index(cfg->bands, i);
+				if (cb->qrvnow == 0) continue;
+				bi = toupper(cb->bandchar) - 'A';
+				qrv_int |= (1 << bi);
+			}
 		}
 	}
 
@@ -1165,8 +1265,10 @@ void sw_qrv_redraw(struct subwin *sw, struct band *band, int flags){
 
     if (!qrv->qrvs->len) return;
     sw_qrv_check_bounds(sw);
+	
 
-    qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
+	qi = NULL;
+	if (sw->cur >= 0 && sw->cur < qrv->qrvs->len) qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, sw->cur);
 //    dbg("%s: cur=%d qi=%p\n", __FUNCTION__, sw->cur, qi);
     if (!qi || (aband != NULL && qrv_skip(qi, aband->bi, 1))) {
         print_text(sw->x, sw->y + sw->h/2, sw->w, "~", COL_INV);
@@ -1661,7 +1763,7 @@ void sw_qrv_choose(struct menu *menu){
 	for (i = 0; i < menu->ni; i++){
 		struct menu_item *mi = menu->items + i;
 		if (!mi->checked) continue;
-		filename = g_strdup_printf("%s/%s/c.txt", tucnak_dir, (char *)mi->data);
+		filename = g_strdup_printf("%s/%s/c.txt", logs_dir, (char *)mi->data);
 		qrv_import_edi(NULL, filename);
 		g_free(filename);
 	}
