@@ -36,7 +36,7 @@ struct qrv_item{
     int qtf;
     double weight;
 
-    // A/C
+    // AS
     time_t ac_start;
     int ac_interval;
     int ac_n;
@@ -66,7 +66,7 @@ void clear_qrv(struct qrvdb *qrvdb);
 void free_qrv(struct qrvdb *qrvdb);
 
 struct qrv_item *qrv_add(gchar *call, gchar *wwl, int qrv_int, int wkd[32], const gchar *text, time_t kst_time);
-struct qrv_item *qrv_kst_add(char *call, char *wwl);
+struct qrv_item *qrv_kst_add(char *call, char *wwl, char *fullname);
 
 void qrv_delete(char *call, int bi);
 int load_qrv_files(struct qrvdb *qrvdb);
