@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
 #include "net.h"
 #include "qrvdb.h"
 #include "qsodb.h"
+#include "rain.h"
 #include "rc.h"
 #include "session.h"
 #include "sked.h"
@@ -64,6 +65,7 @@ int init_ctest(){
     ctest->spypeers = g_ptr_array_new();
     ctest->allb_prefs = g_hash_table_new(g_str_hash, g_str_equal);
     ctest->exclen = 0;
+	ctest->phase = 1;
 
 /*    ctest->serial = 1;*/
     ctest->minute_timer_id=zselect_timer_new(zsel, 100, timer_minute_stats_all, NULL);
@@ -96,13 +98,13 @@ int new_ctest(char *tdate){
         ctest->oldcontest = 0;
     }
     
-    ctest->directory = g_strdup_printf("%s/%s", tucnak_dir, ctest->cdate);
+	ctest->directory = g_strdup_printf("%s/%s", logs_dir, ctest->cdate);
     
     counter=0;
     while (stat(ctest->directory,&st)==0){
         counter++;
         g_free(ctest->directory);
-        ctest->directory = g_strdup_printf("%s/%s.%d", tucnak_dir, ctest->cdate, counter);
+		ctest->directory = g_strdup_printf("%s/%s.%d", logs_dir, ctest->cdate, counter);
     }
         
     if (z_mkdir_p(ctest->directory, 0777)){
@@ -174,6 +176,7 @@ int new_ctest(char *tdate){
 #ifdef Z_HAVE_SDL
     maps_reload();
 	maps_update_showwwls();
+	rain_reload();
 #endif  
     
     return 0; 
@@ -237,7 +240,8 @@ int load_ctest_from_mem(struct contest *ctest, gchar *datedir, GHashTable *hash)
     STORE_HASH_INT(ctest, wwlmult);
     STORE_HASH_INT_DEF(ctest, wwlcfm, 1);
     STORE_HASH_ENUM_DEF(ctest, tttype, enum tttype, TT_RSTS);
-    STORE_HASH_INT(ctest, expmode);
+	STORE_HASH_INT(ctest, expmode);
+	STORE_HASH_INT_DEF(ctest, phase, 1);
     
     set_ctest_title();
    
@@ -513,7 +517,7 @@ void clear_tmpqsos(struct band *b, int set_defaults){
 
     if (!b) return;
 
-    b->dupe_in_tmpqso_index = -1;
+	b->dupe_qso = NULL;
     b->last_item = LI_NONE;
 
     for(i=0;i<TMP_QSOS;i++){
@@ -540,7 +544,8 @@ void clear_tmpqsos(struct band *b, int set_defaults){
         CLEAR_TMPQSO_GINT(b,suspexc);
         CLEAR_TMPQSO_GINT(b,qsl);
         CLEAR_TMPQSO_STRING(b,remark);
-    } 
+		CLEAR_TMPQSO_GINT(b, dupe);
+	}
     CONDGFREE(b->unres);
     CONDGFREE(b->qrv_str);
     CONDGFREE(b->wkd_str);
@@ -653,6 +658,7 @@ struct qso *get_gqso(struct band *b, struct subwin *sw, gint i){
     }
 }
 
+// returns if callsign is worked. Callsign can be worked more times, it returns only one.
 struct qso *get_qso_by_callsign(struct band *b, gchar *callsign){
     char raw[25];
 	struct qso *q;
@@ -677,14 +683,14 @@ struct qso *get_qso_by_callsign(struct band *b, gchar *callsign){
     return NULL;*/
 }
 
-int get_qso_index_by_callsign(struct band *b, gchar *callsign){
+/*int get_qso_index_by_callsign(struct band *b, gchar *callsign){
     struct qso *qso;
     int i;
     char raw[25], qraw[25];
 
     z_get_raw_call(raw, callsign);
     
-              /* TODO callsigns in hash */
+              // TODO callsigns in hash 
     for(i=0;i<b->qsos->len; i++){
         qso = (struct qso *)g_ptr_array_index(b->qsos, i);
 
@@ -694,7 +700,7 @@ int get_qso_index_by_callsign(struct band *b, gchar *callsign){
         if (strcasecmp(raw, qraw)==0) return i;
     }
     return -1;
-}
+}	*/
 
 struct qso *get_qso_by_id(struct band *b, gchar *source, gint ser_id){
     struct qso *qso;
@@ -760,6 +766,7 @@ void add_error(struct band *b, gchar *remark){
     eq->locator  = g_strdup(b->tmpqsos[0].locator&&b->tmpqsos[0].ulocator?b->tmpqsos[0].locator:"");    
     eq->error    = 1;
     eq->remark   = g_strdup(remark?remark:"");
+	eq->phase    = ctest->phase;
     eq->qrg      = 0.0;
     eq->ser_id   = -1;  /* computed by add_qso_to_index */
     
@@ -871,6 +878,7 @@ void activate_band(struct band *b){
     redraw_later();
     maps_reload();
     chart_reload();
+	rain_reload();
 }
 
 
@@ -1089,6 +1097,7 @@ GPtrArray *get_band_qs(struct band *band, gchar *str){
     gchar *c;
     struct qs *qs;
     struct qso *qso;
+	char valid[150];
 
     /*ST_START;*/
     zg_ptr_array_free_items(band->qs);
@@ -1107,18 +1116,20 @@ GPtrArray *get_band_qs(struct band *band, gchar *str){
         if (qs->result1->len == term->y - QSONR_HEIGHT - 4 - cfg->loglines - ctest->spypeers->len - 1) break;
         
         if (qso->callsign && z_strstr(qso->callsign, qs->str)){
+			stats_valid_key_display(valid, qso->callsign, qso->locator, qso->phase, qso->mode);
             if (qso->locator)
-                c=g_strdup_printf("%-10s %-6s%5d/%3d", qso->callsign, qso->locator, (int)qso->qrb, qso->qtf);
+				c = g_strdup_printf("%-10s %-6s%5d/%3d", valid, qso->locator, (int)qso->qrb, qso->qtf);
             else
-                c=g_strdup(qso->callsign);
+				c = g_strdup(valid);
 /*            dbg(",%s", c);*/
             g_ptr_array_add(qs->result1, c);
             continue;
         }
         
         if (qso->locator && z_strstr(qso->locator, qs->str)){
-            if (qso->callsign) 
-                c=g_strdup_printf("%-10s %-6s%5d/%3d", qso->callsign, qso->locator, (int)qso->qrb, qso->qtf);
+			stats_valid_key_display(valid, qso->callsign, qso->locator, qso->phase, qso->mode);
+			if (qso->callsign)
+				c = g_strdup_printf("%-10s %-6s%5d/%3d", valid, qso->locator, (int)qso->qrb, qso->qtf);
             else
                 c=g_strdup_printf("%-10s %-6s%5d/%3d", "", qso->locator, (int)qso->qrb, qso->qtf);
 /*            dbg(",%s", c);*/
@@ -1369,6 +1380,7 @@ void free_ctest(){
     if (!zselect_terminating(zsel))	maps_reload();
 	maps_update_showwwls();
     chart_reload();
+	rain_reload();
 }
 
 
@@ -1511,18 +1523,18 @@ struct zstring *contest_format(struct contest *ctest){
     gchar *ints;
     struct zstring *zs;
 
-    ints = g_strdup_printf("%d;%d;%d;%d;"
-                           "%d;%d;%d;%d;"
-                           "%d;%d;%d;%d;"
-                           "%d;%d;%d;%d;"
-                           "%d;%d;%d;%d;"
-                           "%d;%d",
+	ints = g_strdup_printf("%d;%d;%d;%d;"
+		"%d;%d;%d;%d;"
+		"%d;%d;%d;%d;"
+		"%d;%d;%d;%d;"
+		"%d;%d;%d;%d;"
+		"%d;%d;%d",
         ctest->qsoused, ctest->qsomult, ctest->qsoglob, ctest->wwlused, 
         ctest->wwlcfm,  ctest->wwlbonu, ctest->wwlmult, ctest->excused,
         ctest->exctype, ctest->excbonu, ctest->excmult, ctest->exccfm, 
         ctest->dxcbonu, ctest->dxcmult, ctest->rstused, ctest->defrstr, 
         ctest->qsop_method, ctest->total_method, ctest->tttype, ctest->prefmult, 
-		ctest->prefglob, ctest->expmode);
+		ctest->prefglob, ctest->expmode, ctest->phase);
             
             
     zs = zconcatesc(ints, ctest->tname, ctest->cdate, ctest->pcall, 
@@ -1560,7 +1572,8 @@ void ctest_parse(struct zstring *zstr, struct contest *ctest){
     ctest->tttype       = (enum tttype)atoi(ztokenize(zsint, 0));
     ctest->prefmult     = atoi(ztokenize(zsint, 0));
     ctest->prefglob     = atoi(ztokenize(zsint, 0));
-    ctest->expmode      = atoi(ztokenize(zsint, 0));
+	ctest->expmode      = atoi(ztokenize(zsint, 0));
+	ctest->phase        = atoi(ztokenize(zsint, 0));
 
     STORE_STR3(ctest, tname, zstr, 0);
     STORE_STR3(ctest, cdate, zstr, 0);
@@ -1751,6 +1764,9 @@ int add_qsos_from_swap(struct band *b, FILE *f){
         q->qsonrr   = g_strdup(items[7]);
         q->exc      = g_strdup(items[8]);
         q->locator  = g_strdup(items[9]);
+		if (items[10]){
+			q->phase = atoi(items[10]);
+		}
         q->ser_id=-1; /* computed by add_qso_to_index */
         g_strfreev(items);
         compute_qrbqtf(q);
