@@ -17,6 +17,7 @@
 #ifdef Z_HAVE_SDL
 
 #include "main.h"
+#include "fifo.h"
 #include "map.h"
 #include "rc.h"
 #include "session.h"
@@ -57,11 +58,17 @@ struct rain *init_rain(){
         rain->bwcolors[i] = z_makecol((i + 1) * 8, (i + 1) * 8, (i + 1) * 8);
     }
     
+	rain->maxqrb = cfg->rain_maxqrb;	// km
+	rain->mincolor = cfg->rain_mincolor; // orange
+	rain->minscpdist = cfg->rain_minscpdist; // km
+	rain->scps = g_ptr_array_new_with_free_func((GDestroyNotify)free_rain_scp);
+	rain->scplocs = g_string_sized_new(256);
 
 	if (cfg->rain_meteox){
 		struct rain_provider *provider = g_new0(struct rain_provider, 1);
 		provider->rain = rain;
-        provider->pal = rain->bwcolors;
+		provider->name = "meteox";
+		provider->pal = rain->bwcolors;
 		provider->timer_id = zselect_timer_new(zsel, 1000, rain_meteox_timer, provider); 
 		provider->h1 = -5.72 * M_PI / 180.0;
 		provider->h2 = 18.72 * M_PI / 180.0;
@@ -98,7 +105,8 @@ struct rain *init_rain(){
 	if (cfg->rain_wetteronline){
 		struct rain_provider *provider = g_new0(struct rain_provider, 1);
 		provider->rain = rain;
-        provider->pal = rain->bwcolors;
+		provider->name = "wetteronline";
+		provider->pal = rain->bwcolors;
 		provider->timer_id = zselect_timer_new(zsel, 1000, rain_wetteronline_timer, provider); 
 		provider->h1 = 1.62 * M_PI / 180.0;
 		provider->h2 = 22.52 * M_PI / 180.0;
@@ -135,7 +143,8 @@ struct rain *init_rain(){
 	if (cfg->rain_chmi){
 		struct rain_provider *provider = g_new0(struct rain_provider, 1);
 		provider->rain = rain;
-        provider->pal = rain->bwcolors;
+		provider->name = "chmi";
+		provider->pal = rain->bwcolors;
 		provider->timer_id = zselect_timer_new(zsel, 1000, rain_chmi_timer, provider); 
 		provider->h1 = 12.12 * M_PI / 180.0;
 		provider->h2 = 18.84 * M_PI / 180.0;
@@ -167,7 +176,8 @@ struct rain *init_rain(){
 	if (cfg->rain_weatheronline){
 		struct rain_provider *provider = g_new0(struct rain_provider, 1);
 		provider->rain = rain;
-        provider->pal = rain->bwcolors;
+		provider->name = "weatheronline";
+		provider->pal = rain->bwcolors;
 		provider->timer_id = zselect_timer_new(zsel, 1000, rain_weatheronline_timer, provider); 
 		provider->h1 = -5.6 * M_PI / 180.0; // lon
 		provider->h2 = 37.62 * M_PI / 180.0; // lon
@@ -208,6 +218,102 @@ static gboolean free_rain_hash(gpointer key, gpointer value, gpointer user_data)
 	return TRUE;
 }
 
+struct rain_scp *init_rain_scp(float kx, float ky){
+	struct rain_scp *scp = g_new0(struct rain_scp, 1);
+	scp->kx = kx;
+	scp->ky = ky;
+
+	double qrb, qtf, h, w;
+	km2qrbqtf((int)roundf(kx), (int)roundf(ky), &qrb, &qtf);
+	qrbqtf2hw(gses->myh, gses->myw, qrb, qtf, &h, &w);
+	hw2loc(scp->wwl, h * 180.0 / M_PI, w * 180.0 / M_PI, 6);
+	scp->qrb = (int)round(sqrt(kx*kx + ky*ky));
+	//dbg("SCP %s\n", scp->wwl);
+	return scp;
+}
+
+
+void free_rain_scp(struct rain_scp *scp)
+{
+	g_free(scp);
+}
+
+
+void rain_analyze_scps(struct rain *rain){
+	if (!gses) return;
+
+	g_ptr_array_free(rain->scps, TRUE);// with free func free_rain_scp
+	rain->scps = g_ptr_array_new_with_free_func((GDestroyNotify)free_rain_scp);
+
+	g_string_truncate(rain->scplocs, 0);
+    
+	if (rain->chmi) rain_add_scps(rain->chmi);
+	if (rain->meteox) rain_add_scps(rain->meteox);
+	if (rain->wetteronline) rain_add_scps(rain->wetteronline);
+	if (rain->weatheronline) rain_add_scps(rain->weatheronline);
+	
+	if (rain->scplocs->len > 0){
+		log_addf("Scatterpoints: %s", rain->scplocs->str);
+	}
+}
+
+void rain_add_scps(struct rain_provider *provider){
+	int kx, ky, minkx, minky, maxkx, maxky;//, dummy;
+	//double h, w;
+
+	minkx = -provider->rain->maxqrb & provider->mask;
+	minky = -provider->rain->maxqrb & provider->mask;
+	maxkx = (provider->rain->maxqrb) & provider->mask;
+	maxky = (provider->rain->maxqrb) & provider->mask;
+
+	if (minkx < -32768) minkx = -32768;
+	if (maxkx > 32767) maxkx = 32767;
+	if (minky < -32768) minky = -32768;
+	if (maxky > 32767) maxky = 32767;
+	
+	for (int ci = RAIN_COLORS - 1; ci >= provider->rain->mincolor; ci--){
+		//GHashTable *hash = provider->hashes[ci];
+	
+		//int c = provider->pal[ci];
+		for (ky = minky; ky <= maxky; ky += provider->step){
+			for (kx = minkx; kx <= maxkx; kx += provider->step){
+
+				gpointer key = provider->hash_func(kx, ky, ci);
+				GHashTable *hash = provider->hashes[ci];
+				struct zbinbuf *zbb = (struct zbinbuf *)g_hash_table_lookup(hash, key);
+				//dbg("kx=%d   \tky=%d\n", kx, ky);
+				if (zbb == NULL) continue;
+
+				int i;
+				for (i = 0; i <= zbb->len - (int)sizeof(struct rain_km); i += sizeof(struct rain_km)){
+					struct rain_km *km = (struct rain_km *)(zbb->buf + i);
+					if (rain_scp_exists(provider, km->kx, km->ky)) continue;
+
+					struct rain_scp *scp = init_rain_scp(km->kx, km->ky);
+					g_ptr_array_add(provider->rain->scps, scp);
+
+					if (scp->qrb <= provider->rain->maxqrb){
+						if (provider->rain->scplocs->len > 0) g_string_append(provider->rain->scplocs, " ");
+						g_string_append(provider->rain->scplocs, scp->wwl);
+					}
+				}
+			}
+		}
+
+	}
+}
+
+int rain_scp_exists(struct rain_provider *prov, float kx, float ky){
+	int i;
+	for (i = 0; i < prov->rain->scps->len; i++){
+		struct rain_scp *scp = (struct rain_scp *)g_ptr_array_index(prov->rain->scps, i);
+		float dist = sqrtf(powf(scp->kx - kx, 2) + powf(scp->ky - ky, 2));
+		if (dist < prov->rain->minscpdist) return 1;
+	}
+	return 0;
+}
+
+
 void free_rain_provider(struct rain_provider *provider){
 	int i;
 
@@ -240,6 +346,7 @@ void free_rain(struct rain *rain){
 
     g_free(rain->colors);
     g_free(rain->bwcolors);
+	g_string_free(rain->scplocs, TRUE);
     g_free(rain);
 }
 
@@ -267,6 +374,8 @@ static void rain_provider_add(struct rain_provider *provider, int ix, int iy, in
 	hw2km_f(gses->myh, gses->myw, hh2, ww1, &km.kx2, &km.ky2);
 	hw2km_f(gses->myh, gses->myw, hh1, ww2, &km.kx3, &km.ky3);
 	hw2km_f(gses->myh, gses->myw, hh2, ww2, &km.kx4, &km.ky4);
+	km.kx = (km.kx1 + km.kx2) / 2;
+	km.ky = (km.ky1 + km.ky2) / 2;
 
 	key = provider->hash_func(km.kx1, km.ky1, ci);
 	hash = provider->hashes[ci];
@@ -315,6 +424,37 @@ void rain_linear_img2hw(struct rain_provider *provider, int ix, int iy, double *
 }
 
 
+/*static void rain_provider_reload(struct rain_provider *provider, void (*handler)(void*)){
+	if (!provider) return;
+
+	if (provider->timer_id <= 0) return;
+
+	int i;
+	for (i = 0; i < RAIN_COLORS; i++) {
+		GHashTable *hash = provider->hashes[i];
+		g_hash_table_foreach(hash, rain_truncate_hash, NULL);
+	}
+
+	zselect_timer_kill(zsel, provider->timer_id);
+	zselect_timer_new(zsel, rand()%2000, handler, provider);
+} */
+
+void rain_reload(){
+	if (!grain) return;
+
+	/*rain_provider_reload(grain->meteox, rain_meteox_timer);
+	rain_provider_reload(grain->wetteronline, rain_wetteronline_timer);
+	rain_provider_reload(grain->chmi, rain_chmi_timer);
+	rain_provider_reload(grain->weatheronline, rain_weatheronline_timer);
+	//rain_provider_reload(grain->rainviewer, rain_rainv);
+	rain_analyze_scps(grain); // only truncate*/
+
+	free_rain(grain);
+	grain = init_rain();
+}
+
+
+
 /* meteox.com */
 void rain_meteox_timer(void *arg){
     char *url;
@@ -322,6 +462,8 @@ void rain_meteox_timer(void *arg){
     struct tm tm;
     struct rain_provider *provider = (struct rain_provider*)arg;
 
+	provider->timer_id = 0;
+
     tt = time(NULL);
 	tt += provider->ofs_min * 60;
     gmtime_r(&tt, &tm);
@@ -332,7 +474,7 @@ void rain_meteox_timer(void *arg){
 
 	dbg("rain_timer %d.%d.%d %d:%02d:%02d -> (%02d)\n", tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday, tm.tm_hour, tm.tm_min, tm.tm_sec, (tm.tm_min / 15) * 15); 
 
-    url = g_strdup_printf("http://www.meteox.com/images.aspx?jaar=%04d&maand=%02d&dag=%02d&uur=%02d&minuut=%02d", 
+    url = g_strdup_printf("https://www.meteox.com/images.aspx?jaar=%04d&maand=%02d&dag=%02d&uur=%02d&minuut=%02d", 
         tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
         tm.tm_hour, tm.tm_min);
     //url = g_strdup("http://www.meteox.com/images.aspx?jaar=2016&maand=07&dag=08&uur=20&minuut=00"); 
@@ -366,7 +508,7 @@ void rain_meteox_downloaded(struct zhttp *http){
 	}
 	
 
-	if (strncmp(http->response->buf + http->dataofs, "GIF89a", 6) == 0){ // image not available, go to the past
+	if (provider->ofs_min >= -60 && strncmp(http->response->buf + http->dataofs, "GIF89a", 6) != 0){ // image not available, go to the past
 		provider->ofs_min -= 15;
 		dbg("set meteox_ofs_min to %d\n", provider->ofs_min);
 		zhttp_free(http);
@@ -393,7 +535,8 @@ void rain_meteox_downloaded(struct zhttp *http){
 			rain_provider_draw_colors(provider, provider->img);
 			zpng_save(provider->img, "_meteox2.png", NULL);
 		}
-		
+		rain_analyze_scps(provider->rain);
+
         //provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_meteox_timer, provider);
 	    gettimeofday(&tv, NULL);
     	remains = 900000 - ((tv.tv_sec % 900) * 1000 + tv.tv_usec/1000);
@@ -491,6 +634,8 @@ void rain_wetteronline_timer(void *arg){
     struct tm tm;
     struct rain_provider *provider = (struct rain_provider*)arg;
 
+	provider->timer_id = 0;
+
     tt = time(NULL);
 	tt += provider->ofs_min * 60;
     gmtime_r(&tt, &tm);
@@ -525,6 +670,15 @@ void rain_wetteronline_downloaded(struct zhttp *http){
 	
 	if (provider->rain->debug) zbinbuf_write_to_file(http->response, "_wetteronline.png", http->dataofs, http->response->len - http->dataofs);
 
+	if (http->response->len <= http->dataofs + 8 ||
+		strncmp(http->response->buf + http->dataofs, "\x89PNG\r\n\x1a\n", 8) != 0){ // image not available
+		dbg("No PNG returned\n");
+		provider->pal = provider->rain->bwcolors;
+		provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_wetteronline_timer, provider);
+		goto x;
+	}
+
+
     newimg = zpng_create(http->response->buf + http->dataofs, http->response->len - http->dataofs);
     if (newimg == NULL){
         dbg("Can't read bitmap\n");
@@ -541,12 +695,14 @@ void rain_wetteronline_downloaded(struct zhttp *http){
 			rain_provider_draw_colors(provider, provider->img);
 			zpng_save(provider->img, "_wetteronline2.png", NULL);
 		}
+		rain_analyze_scps(provider->rain);
 
 		//provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_wetteronline_timer, provider);
 	    gettimeofday(&tv, NULL);
     	remains = 300000 - ((tv.tv_sec % 300) * 1000 + tv.tv_usec/1000) + 500;
 	    provider->timer_id = zselect_timer_new(zsel, remains, rain_wetteronline_timer, provider);
     }
+x:;
 	zhttp_free(http);
 	provider->http = NULL;
 	sw_set_gdirty(SWT_MAP);
@@ -622,6 +778,8 @@ void rain_chmi_timer(void *arg){
     struct tm tm;
     struct rain_provider *provider = (struct rain_provider*)arg;
 
+	provider->timer_id = 0;
+
     tt = time(NULL);
     gmtime_r(&tt, &tm);
 	dbg("%02d:%02dZ: ", tm.tm_hour, tm.tm_min);
@@ -635,12 +793,12 @@ void rain_chmi_timer(void *arg){
 
     //dbg("rain_timer %d.%d.%d %d.%02d.%02d\n", tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday, tm.tm_hour, tm.tm_min, tm.tm_sec); 
 
-    url = g_strdup_printf("http://portal.chmi.cz/files/portal/docs/meteo/rad/inca-cz/data/czrad-z_max3d/pacz2gmaps3.z_max3d.%04d%02d%02d.%02d%02d.0.png", 
+    url = g_strdup_printf("https://www.chmi.cz/files/portal/docs/meteo/rad/inca-cz/data/czrad-z_max3d/pacz2gmaps3.z_max3d.%04d%02d%02d.%02d%02d.0.png", 
         tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
 		tm.tm_hour, tm.tm_min); 
     //url = g_strdup_printf("http://portal.chmi.cz/files/portal/docs/meteo/rad/inca-cz/data/czrad-z_max3d/pacz2gmaps3.z_max3d.20160708.1800.0.png");
 
-    provider->http = zhttp_init();
+	provider->http = zhttp_init();
     dbg("CHMI url = '%s'\n", url);
     zhttp_get(provider->http, zsel, url, rain_chmi_downloaded, provider);
     g_free(url);
@@ -651,6 +809,11 @@ void rain_chmi_downloaded(struct zhttp *http){
     struct rain_provider *provider = (struct rain_provider*)http->arg;
     SDL_Surface *newimg;
     
+
+	if (http->state == ZHTTPST_ERROR && http->errorstr){
+		dbg("ERROR rain_chmi_downloaded: %s\n", http->errorstr);
+	}
+
     if (provider->timer_id) {
         zselect_timer_kill(zsel, provider->timer_id);
         provider->timer_id = 0;
@@ -674,7 +837,7 @@ void rain_chmi_downloaded(struct zhttp *http){
 
     newimg = zpng_create(http->response->buf + http->dataofs, http->response->len - http->dataofs);
     if (newimg == NULL){
-        dbg("Can't read bitmap\n");
+        dbg("Can't read CHMI bitmap\n");
         provider->pal = provider->rain->bwcolors;
 		provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_chmi_timer, provider);
     }else{
@@ -685,6 +848,8 @@ void rain_chmi_downloaded(struct zhttp *http){
         provider->img = newimg;
         provider->pal = provider->rain->colors;
         rain_chmi_load(provider);
+		rain_analyze_scps(provider->rain);
+
 		//provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_chmi_timer, provider);
 		provider->timer_id = zselect_timer_new(zsel, 9 * 60 * 1000, rain_chmi_timer, provider);
     } 
@@ -742,6 +907,8 @@ void rain_weatheronline_timer(void *arg){
     struct tm tm;
     struct rain_provider *provider = (struct rain_provider*)arg;
 
+	provider->timer_id = 0;
+
     tt = time(NULL);
 	tt = ((tt + 1800) / 3600) * 3600;
     gmtime_r(&tt, &tm);
@@ -771,6 +938,14 @@ void rain_weatheronline_downloaded(struct zhttp *http){
 	
 	if (provider->rain->debug) zbinbuf_write_to_file(http->response, "_weatheronline.png", http->dataofs, http->response->len - http->dataofs);
 
+	if (http->response->len <= http->dataofs + 8 ||
+		strncmp(http->response->buf + http->dataofs, "\x89PNG\r\n\x1a\n", 8) != 0){ // image not available
+		dbg("No PNG returned\n");
+		provider->pal = provider->rain->bwcolors;
+		provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_wetteronline_timer, provider);
+		goto x;
+	}
+
     newimg = zpng_create(http->response->buf + http->dataofs, http->response->len - http->dataofs);
     if (newimg == NULL){
         dbg("Can't read bitmap\n");
@@ -787,12 +962,14 @@ void rain_weatheronline_downloaded(struct zhttp *http){
 			rain_provider_draw_colors(provider, provider->img);
 			zpng_save(provider->img, "_weatheronline2.png", NULL);
 		}
+		rain_analyze_scps(provider->rain);
 
 		//provider->timer_id = zselect_timer_new(zsel, 1 * 60 * 1000, rain_weatheronline_timer, provider);
 	    gettimeofday(&tv, NULL);
     	remains = 300000 - ((tv.tv_sec % 300) * 1000 + tv.tv_usec/1000) + 500;
 	    provider->timer_id = zselect_timer_new(zsel, remains, rain_weatheronline_timer, provider);
     }
+x:;
 	zhttp_free(http);
 	provider->http = NULL;
 	sw_set_gdirty(SWT_MAP);
@@ -889,7 +1066,7 @@ void rain_weatheronline_load(struct rain_provider *provider){
                 if (r == 148 && g == 148 && b == 148) continue;
                 if (r == 129 && g == 129 && b == 129) continue;
                 if (r == 200 && g == 200 && b == 200) continue;
-                dbg("unknown color at [%d,%d] = %d, %d, %d\n", ix, iy, r, g, b);
+                //dbg("unknown color at [%d,%d] = %d, %d, %d\n", ix, iy, r, g, b);
             }
 		}
 	}
