@@ -22,6 +22,7 @@ struct zhttp;
 struct rain;
 
 struct rain_km{
+	float kx, ky;     // center
 	float kx1, ky1;	  // left upper
 	float kx2, ky2;	  // right upper
 	float kx3, ky3;	  // left lower
@@ -60,6 +61,13 @@ struct rain_provider{
 	int rv_cnt;
 };
 
+struct rain_scp{
+	char wwl[7];
+	//double h, w;
+	int kx, ky;
+	int qrb;
+};
+
 struct rain{
     int *colors, *bwcolors;
 	int debug;
@@ -69,14 +77,28 @@ struct rain{
 	struct rain_provider *chmi;
 	struct rain_provider *weatheronline;
 	struct rain_provider *rainviewer;
+
+	int maxqrb; // typ. 300km
+	int mincolor; // typ. 11 (orange)
+	int minscpdist; // typ 20km
+	GPtrArray *scps; // of rain_scp
+	GString *scplocs; // loc1 loc2 ... locn
 };
 
 extern struct rain *grain;
 
 struct rain *init_rain(void);
 void free_rain(struct rain *rain);
+
+struct rain_scp *init_rain_scp(float kx, float ky);
+void free_rain_scp(struct rain_scp *scp);
+void rain_analyze_scps(struct rain *rain);
+void rain_add_scps(struct rain_provider *prov);
+int rain_scp_exists(struct rain_provider *prov, float kx, float ky);
+
 void free_rain_provider(struct rain_provider *provider);
 void rain_linear_img2hw(struct rain_provider *provider, int ix, int iy, double *h, double *w);
+void rain_reload(void);
 
 void rain_meteox_timer(void *arg);
 void rain_meteox_downloaded(struct zhttp *http);
