@@ -76,6 +76,11 @@ struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
             break;
 #ifdef HAVE_HAMLIB
         case ROT_HAMLIB:
+			if (strlen(crot->rot_filename) == 0){
+				log_addf("Can't init rotator, empty file name");
+				g_free(rot);
+				return NULL;
+			}
             rot->rot = rot_init(crot->rot_model);
 			if (!rot->rot){
 				log_addf(VTEXT(T_UNKNOWN_ROTNR_OR_INIT_ERROR), crot->rot_model);
@@ -87,18 +92,21 @@ struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
 
 				return NULL;
 			}
+			TRROT(0, "rot_init(model %d) OK", rot->rot->caps->rot_model);
+
 			if (crot->rot_model > 0){
 #ifdef Z_MSC_MINGW_CYGWIN
 				if (strchr(crot->rot_filename, '\\') == NULL && z_strcasestr(crot->rot_filename, "COM") != NULL){
 					char *c = g_strdup_printf("\\\\.\\%s", crot->rot_filename);
-					safe_strncpy(rot->rot->state.rotport.pathname, c, FILPATHLEN);
+					safe_strncpy(rot->rot->state.rotport.pathname, c, FILPATHLEN - 1);
 					g_free(c);
 				}
 				else
 #endif
 				{
-					safe_strncpy(rot->rot->state.rotport.pathname, crot->rot_filename, FILPATHLEN);
+					safe_strncpy(rot->rot->state.rotport.pathname, crot->rot_filename, FILPATHLEN - 1);
 				}
+				TRROT(0, "rot->rot->state.rotport.pathname='%s'", rot->rot->state.rotport.pathname);
 			}
 
             rot->hl_azim = -1;
@@ -624,9 +632,10 @@ gpointer rot_hamlib_main(gpointer xxx){
 
     ret = rot_open(rot->rot);
     if (ret != RIG_OK){
+		TRROT(1, "rot_open(model %d) failed, code %d", rot->rot->caps->rot_model, ret);
         return NULL;
     }
-
+	TRROT(1, "rot_open(model %d) OK", rot->rot->caps->rot_model);
 
     while(!rot->hl_thread_break){
         if (rot->hl_give_me_chance) {
@@ -639,19 +648,23 @@ gpointer rot_hamlib_main(gpointer xxx){
             elevation_t el = 0;
 
             ret = rot_set_position(rot->rot, az, el);
-            rot->hl_azim = -1;
+			TRROT(1, "rot_set_position(az %3.1f, el %3.1f) = %d", (double)az, (double)el, ret);
+			rot->hl_azim = -1;
         }
 
-        if (rot_get_position(rot->rot, &azimuth, &elevation) == RIG_OK){
-            qtf = (int)azimuth;
-            if (qtf != rot->oldqtf){
-                rot->oldqtf = qtf;
-               // g_snprintf(s, sizeof(s), "%d", qtf);
-                zselect_msg_send(zsel, "ROT;%s;QTF;%d", rot->rotstr, qtf);
-               // ret = zwrite(tpipe->threadpipe_write, zconcatesc("ROT", rot->rotstr, "QTF", s, NULL));
-                //    dbg("zwrite ret=%d\n", ret);
-            }
-
+		ret = rot_get_position(rot->rot, &azimuth, &elevation);
+		if (ret == RIG_OK){
+			TRROT(1, "rot_get_position() = az %3.1f, el %3.1f", (double)azimuth, (double)elevation);
+			qtf = (int)azimuth;
+			if (qtf != rot->oldqtf){
+				rot->oldqtf = qtf;
+				// g_snprintf(s, sizeof(s), "%d", qtf);
+				zselect_msg_send(zsel, "ROT;%s;QTF;%d", rot->rotstr, qtf);
+				// ret = zwrite(tpipe->threadpipe_write, zconcatesc("ROT", rot->rotstr, "QTF", s, NULL));
+				//    dbg("zwrite ret=%d\n", ret);
+			}
+		}else{
+			TRROT(1, "rot_get_position() failed, ret=%d", ret);
         }
 
 
@@ -664,7 +677,7 @@ gpointer rot_hamlib_main(gpointer xxx){
 			}
 		}
     }
-    dbg("rot_hl_main exiting\n");
+    TRROT(1, "rot_hl_main exiting\n");
     rot_close(rot->rot);
 
     return NULL;
