@@ -37,10 +37,13 @@
 
 int main(int argc, char *argv[]){
     int ret, fd, freq, arg;
+    int quiet = 0;
+
+    if (argc > 1 && strcmp(argv[1], "-q") == 0) quiet = 1;
 
     fd=open("/dev/console", O_WRONLY|O_SYNC);
     if (fd<0) {
-        fprintf(stderr, "Can't open /dev/console, error %d %s\n", errno, strerror(errno));
+        if (!quiet) fprintf(stderr, "Can't open /dev/console, error %d %s\n", errno, strerror(errno));
         return 1;
     }
 
@@ -48,14 +51,14 @@ int main(int argc, char *argv[]){
         freq = atoi(argv[1]);
         if (freq){ 
             arg=1193180/freq;
-            printf("%d\n", 1193180/arg); 
+            if (!quiet) printf("%d\n", 1193180/arg); 
         }else 
             arg=0;
             
         ret=ioctl(fd, KIOCSOUND, arg);
         if (ret){
             close(fd);
-            fprintf(stderr, "Can't run IOCTL KIOCSOUND, error %d %s\n", errno, strerror(errno));
+            if (!quiet) fprintf(stderr, "Can't run IOCTL KIOCSOUND, error %d %s\n", errno, strerror(errno));
             return 1;
         }
         close(fd);
@@ -66,7 +69,7 @@ int main(int argc, char *argv[]){
         ret=read(0, &freq, sizeof(freq));
         if (ret!=sizeof(freq)){
             close(fd);
-            if (ret>0) fprintf(stderr, "Can't read %d bytes from /dev/console (only %d), error %d %s\n", (int)sizeof(freq), ret, errno, strerror(errno));
+            if (ret>0 && !quiet) fprintf(stderr, "Can't read %d bytes from /dev/console (only %d), error %d %s\n", (int)sizeof(freq), ret, errno, strerror(errno));
             return 1;
         }
         if (freq==-1) break;
@@ -79,7 +82,7 @@ int main(int argc, char *argv[]){
         ret=ioctl(fd, KIOCSOUND, arg);
         if (ret){
             close(fd);
-            fprintf(stderr, "Can't run IOCTL KIOCSOUND, error %d %s\n", errno, strerror(errno));
+            if (!quiet) fprintf(stderr, "Can't run IOCTL KIOCSOUND, error %d %s\n", errno, strerror(errno));
             return 1;
         }
 
