@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -108,7 +108,7 @@ struct stats *init_stats(){
     st->dxcs  = g_hash_table_new(g_str_hash, g_str_equal);
     st->prefs = g_hash_table_new(g_str_hash, g_str_equal);
     st->excs  = g_hash_table_new(g_str_hash, g_str_equal);
-    st->calls = g_hash_table_new(g_str_hash, g_str_equal);
+	st->valid = g_hash_table_new(g_str_hash, g_str_equal);
     st->hours = g_hash_table_new(g_str_hash, g_str_equal);
     
     clear_stats(st);
@@ -125,7 +125,7 @@ void free_stats(struct stats *st){
     g_hash_table_destroy(st->dxcs);
     g_hash_table_destroy(st->prefs);
     g_hash_table_destroy(st->excs);
-    g_hash_table_destroy(st->calls);
+	g_hash_table_destroy(st->valid);
     g_hash_table_destroy(st->hours);
     zg_free0(st->mycontinent);
     zg_free0(st->mydxcc);
@@ -154,7 +154,7 @@ void clear_stats(struct stats *st){
     g_hash_table_foreach_remove(st->dxcs,  free_gpointer_item, NULL);
     g_hash_table_foreach_remove(st->prefs, free_gpointer_item, NULL);
     g_hash_table_foreach_remove(st->excs,  free_gpointer_item, NULL);
-    g_hash_table_foreach_remove(st->calls, free_gpointer_item, NULL);
+	g_hash_table_foreach_remove(st->valid, zg_hash_free_key, NULL);
     g_hash_table_foreach_remove(st->hours, free_gpointer_item, NULL);
     
     if (st->odxcall)     {g_free(st->odxcall);     st->odxcall      = NULL;}
@@ -169,6 +169,8 @@ void clear_stats(struct stats *st){
     st->mycontinent = g_strdup(dxi->continent);
     zg_free0(st->mydxcc);
     st->mydxcc = g_strdup(get_dxcc(dw, s, ctest->pcall));
+
+	st->oldphase = 1;
 }
 
 int find_preferred_dxc(int type, char *dxc){
@@ -254,18 +256,14 @@ void update_stats(struct band *band, struct stats *st, struct qso *q){
 /*    dbg("update_stats(%s) calls->size=%d \n", q->qsonrs, g_hash_table_size(st->calls));
     dbg("   dupe=%d  qsop=%d \n", q->dupe, q->qsop);*/
     
-    z_get_raw_call(s, q->callsign);
-    if (z_call_is_rover(q->callsign) && q->locator){
-        strcat(s, "_");
-        safe_strncpy0(s + strlen(s), q->locator, 4+1);
-    } 
+	char *valid_key = stats_valid_key(s, q->callsign, q->locator, q->phase, q->mode);
+    
+    dbg("update_stats(%s)\n", valid_key);    
 
-    //dbg("update_stats(%s)\n", s);    
-
-	if (g_hash_table_lookup_extended(st->calls, s, &orig_key, (gpointer*) &orig_value) && ctest->expmode == 0){
+	if (g_hash_table_lookup_extended(st->valid, valid_key, &orig_key, (gpointer*)&orig_value) && ctest->expmode == 0){
         SAD_INT(dupe,1);
     }else{
-        g_hash_table_insert(st->calls, g_strdup(s), NULL);
+		g_hash_table_insert(st->valid, g_strdup(valid_key), q);
         SAD_INT(dupe,0);
     }
     
@@ -395,9 +393,12 @@ void update_stats(struct band *band, struct stats *st, struct qso *q){
             break;
 		case 20: /* WWL ring Contest Lombardia */
 			qsop = (qsopwr(ctest->pwwlo, q->locator) - 1) * ctest->qsomult * band->qsomultb;
+			break;
         case 21: // R-Contest
-          qsop = 1;
-        break;
+            qsop = 1;
+			break;
+		case 22: /* Moon contest */
+			qsop = iaru_round(q->qrb) * ctest->qsomult * band->qsomultb; // same as IARU
 			break;
 
     }
@@ -584,6 +585,14 @@ void update_stats(struct band *band, struct stats *st, struct qso *q){
         anew &= ~NEW_MULT;
     
     SAD_INT(new_,anew);
+
+	if (q->phase != st->oldphase){
+		q->new_ |= NEW_PHASE;
+		st->oldphase = q->phase;
+	}else{
+		q->new_ &= ~NEW_PHASE;
+	}
+
     
 x:;    
     if (band->stats==st) MUTEX_UNLOCK(band->stats);
@@ -1226,7 +1235,7 @@ void recalc_statsfifo(struct band *b){
         fifo_addf(F, VTEXT(T_SF_ALLBPTS), ctest->allb_ntotal);
     }
     fifo_addf(F, VTEXT(T_SF_QSOS), b->stats->nqsos);  
-    fifo_addf(F, VTEXT(T_SF_VQSO), g_hash_table_size(b->stats->calls));
+	fifo_addf(F, VTEXT(T_SF_VQSO), g_hash_table_size(b->stats->valid));
     fifo_addf(F, VTEXT(T_SF_QSOP), b->stats->nqsop);
     fifo_addf(F, VTEXT(T_SF_PTS), b->stats->ntotal);
     
@@ -1561,3 +1570,95 @@ int qsomult16(struct band *band){
 
     return qsomult;
 }
+
+	
+char *stats_valid_key(char *buf, const char *call, const char *wwl, const int phase, const enum modes mode){
+	z_get_raw_call(buf, call);
+	if (phase > 1){
+		sprintf(buf + strlen(buf), "_%d", phase);
+	}
+	if (z_call_is_rover(call) && wwl){
+		strcat(buf, "_");
+		safe_strncpy0(buf + strlen(buf), wwl, 4 + 1);
+	}
+	if (ctest->qsop_method == 22){ // Moon contest
+		switch (mode){
+		case MOD_NONE:
+		case MOD_SSB_SSB:
+		case MOD_SSB_CW:
+		case MOD_CW_SSB:
+		case MOD_AM_AM:
+		case MOD_FM_FM:
+			strcpy(buf + strlen(buf), "_PH");
+			break;
+		case MOD_CW_CW:
+			strcpy(buf + strlen(buf), "_CW");
+			break;
+		case MOD_RTTY_RTTY:
+		case MOD_SSTV_SSTV:
+		case MOD_ATV_ATV:
+			strcpy(buf + strlen(buf), "_DI");
+			break;
+		}
+	}
+	return buf;
+}
+
+// versus stats_valid_key - not raw call
+char *stats_valid_key_display(char *buf, const char *call, const char *wwl, const int phase, const enum modes mode){
+	strcpy(buf, call);
+	if (phase > 1){
+		sprintf(buf + strlen(buf), "_%d", phase);
+	}
+	if (z_call_is_rover(call) && wwl){
+		strcat(buf, "_");
+		safe_strncpy0(buf + strlen(buf), wwl, 4 + 1);
+	}
+	if (ctest->qsop_method == 22){ // Moon contest
+		switch (mode){
+			case MOD_NONE:
+			case MOD_SSB_SSB:
+			case MOD_SSB_CW:
+			case MOD_CW_SSB:
+			case MOD_AM_AM:
+			case MOD_FM_FM:
+				strcpy(buf + strlen(buf), "_PH");
+				break;
+			case MOD_CW_CW:
+				strcpy(buf + strlen(buf), "_CW");
+				break;
+			case MOD_RTTY_RTTY:
+			case MOD_SSTV_SSTV:
+			case MOD_ATV_ATV:
+				strcpy(buf + strlen(buf), "_DI");
+				break;
+		}
+	}
+	return buf;
+}
+
+static void dump(gpointer key, gpointer value, gpointer userdata)
+{
+	g_string_append_printf((GString *)userdata, "%s ", key);
+}
+
+struct qso *stats_get_dupe(struct stats *st, const char *call, const char *wwl, const int phase, const enum modes mode){
+	char s[125];
+	char *valid_key = stats_valid_key(s, call, wwl, phase, mode);
+	
+	//if (z_call_is_rover(call)) return NULL;
+	if (ctest->expmode) return NULL;
+	struct qso *ret = g_hash_table_lookup(st->valid, valid_key);
+	
+	GString *gs = g_string_sized_new(1000);
+	g_hash_table_foreach(st->valid, dump, gs);
+	dbg("stats_get_dupe = %s (%s)\n", valid_key, gs->str);
+	if (ret != NULL)
+		dbg("  ret = %s %-3s\n", ret->callsign, ret->qsonrs);
+	else
+		dbg("  ret = NULL\n");
+	g_string_free(gs, TRUE);
+
+	return ret;
+}
+
