@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -1444,6 +1444,7 @@ void sw_qsos_redraw(struct subwin *sw, struct band *band, int flags){
         if (q->new_ & NEW_PREF)                    strcat(new_, "p");
         if (q->qsl)                             strcat(new_, "q");
         if (q->remark && strlen(q->remark)>0)   strcat(new_, "r");
+		if (q->new_ & NEW_PHASE) strcat(new_, "h");
 
         if (!q->dupe) sprintf(qsop,"%6d", q->qsop);
         else strcpy(qsop, "DUPE");
@@ -2363,7 +2364,7 @@ void sw_export_lines(struct subwin *sw, char *fname){
 
 int sw_shake_tmo = -1;
 void sw_shake(struct subwin *sw, int down){
-#ifdef Z_HAVE_SDL
+#if defined(Z_HAVE_SDL) && !defined(Z_MACOS)
 	SDL_Surface *old;
 	SDL_Rect src, dst, fill;
     int len;
@@ -2407,35 +2408,40 @@ void sw_shake(struct subwin *sw, int down){
 		dst.y = src.y + h;
 		dst.w = src.w;
 		dst.h = src.h - h;
-		src.h -= h;
-		SDL_BlitSurface(sdl->screen, &src, sdl->screen, &dst);
+
 		fill.x = src.x;
 		fill.y = src.y;
 		fill.w = src.w;
 		fill.h = h;
+
+		src.x = 0;
+		src.y = 0;
+		src.h -= h;
+		SDL_BlitSurface(old, &src, sdl->screen, &dst);
 		SDL_FillRect(sdl->screen, &fill, z_makecol(0, 0, 0));
-	}else{
+	}
+	else{
 		dst.x = src.x;
 		dst.y = src.y;
 		dst.w = src.w;
 		dst.h = src.h - h;
-		src.y += h;
-		src.h -= h;
-		SDL_BlitSurface(sdl->screen, &src, sdl->screen, &dst);
+
 		fill.x = src.x;
 		fill.y = src.y + src.h - h;
 		fill.w = src.w;
 		fill.h = h;
+
+		src.x = 0;
+		src.y = 0;
+		src.y += h;
+		src.h -= h;
+		SDL_BlitSurface(old, &src, sdl->screen, &dst);
 		SDL_FillRect(sdl->screen, &fill, z_makecol(0, 0, 0));
 	}
 	
 	SDL_UpdateRect(sdl->screen, 0, 0, 0, 0);
-/*#ifdef Z_ANDROID
-	usleep(70000);
-#else
-	usleep(20000);
-#endif*/
 	usleep(100000);
+
 	dst.x = sw->x * FONT_W;
 	dst.y = sw->y * FONT_H;
 	dst.w = sw->w * FONT_W;
@@ -2520,6 +2526,7 @@ void sw_highlight(struct subwin *sw, const char *text, const char *needle, int c
 
 void sw_set_gdirty(enum sw_type type){
 #ifdef Z_HAVE_SDL    
+	if (!gses) return;
 	int i;
 	for (i = 0; i < gses->subwins->len; i++){
         struct subwin *sw = (struct subwin *)g_ptr_array_index(gses->subwins, i);
