@@ -118,6 +118,8 @@ struct subwin {
 	int chat; // unix chat, not KST chat
 	int first_shus;
 	char *callunder;
+	GPtrArray* callsunder;
+	int callunderx, callundery;
 	double qrg; // kHz
 	char *pattern;
 	int dxc_from_net;
@@ -137,6 +139,7 @@ struct subwin {
 	int sdr_by;
 	int side_top, side_bott;
 	int shaking;
+	struct timeval kst_latest_data;
 };
 
 struct config_subwin{
