@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -626,7 +626,7 @@ test_queue:
         xwin = is_xterm() * ENV_XWIN + can_twterm() * ENV_TWIN + (!!getenv("STY")) * ENV_SCREEN;
         if (!(ts = getenv("TERM"))) ts = "";
 //        dbg("in_term ts=%s\n", ts);
-        strcpy(term->term, ts);
+        g_strlcpy(term->term, ts, MAX_TERM_LEN);
         term->environment=xwin;
         sync_term_specs();
     }
@@ -868,7 +868,7 @@ void term_redraw_screen()
                 int i;
                 for (i = x - cx; i >= 0; i--) PRINT_CHAR(p - i);
             } else {
-                g_string_sprintfa(a, "\033[%d;%dH", y + 1, x + 1);
+                g_string_append_printf(a, "\033[%d;%dH", y + 1, x + 1);
                 cx = x; cy = y;
                 pc:
                 PRINT_CHAR(p);
@@ -883,7 +883,7 @@ void term_redraw_screen()
     if (a->len || term->cx != term->lcx || term->cy != term->lcy) {
         term->lcx = term->cx;
         term->lcy = term->cy;
-        g_string_sprintfa(a, "\033[%d;%dH", term->cy + 1, term->cx + 1);
+        g_string_append_printf(a, "\033[%d;%dH", term->cy + 1, term->cx + 1);
     }
     hard_write(term->fdout, a->str, a->len);
 	
@@ -902,7 +902,7 @@ void destroy_terminal(void *arg)
     g_free(term->screen);
     term->screen=NULL;
     g_free(term->last_screen);
-    term->screen=NULL;
+    term->last_screen=NULL;
     zselect_set(zsel, term->fdin, NULL, NULL, NULL, NULL);
     g_free(term->input_queue);
     if (term->blocked != -1) {
