@@ -85,6 +85,7 @@ void init_trigs(void){
     gtrigs->qrg = 0.0;
     gtrigs->rit = 0;
 	gtrigs->trigs = g_ptr_array_new();
+	gtrigs->split_vfo = RIG_VFO_MAIN;
 
 	for (i = 0; i < cfg->crigs->len; i++){
 		struct config_rig *crig = (struct config_rig *)g_ptr_array_index(cfg->crigs, i);
@@ -258,6 +259,30 @@ void trigs_set_ptt(struct trigs *trigs, int ptt){
 	}
 }
 
+void trigs_toggle_split_vfo(struct trigs *trigs){
+	int i;
+
+	if (trigs == NULL) return;
+
+	// parameters obtained experimentally on IC-7610
+	if (gtrigs->split_vfo == RIG_VFO_MAIN) {
+		gtrigs->split_vfo = RIG_VFO_SUB;
+	}
+	else{
+		gtrigs->split_vfo = RIG_VFO_MAIN;
+	}
+
+	TRTR(0, "trigs_toggle_split_vfo  split_vfo=%s", gtrigs->split_vfo == RIG_VFO_MAIN ? "MAIN" : "SUB");
+	
+	for (i = 0; i < trigs->trigs->len; i++){
+		struct trig *trig;
+		trig = (struct trig *)g_ptr_array_index(trigs->trigs, i);
+		trig_toggle_split_vfo(trig);
+	}
+}
+
+
+
 // ---------------- trig functions
 
 struct trig *init_trig(struct config_rig *crig){
@@ -419,6 +444,19 @@ void trig_set_ptt(struct trig *trig, ptt_t ptt){
     trig_job_add(trig, job);
 }
 
+void trig_toggle_split_vfo(struct trig *trig){
+	struct trig_job *job;
+
+	//log_addf("trig_toggle_split_vfo trig=%p  split_vfo=%d", trig, (int)gtrigs->split_vfo);
+
+	if (!trig) return;
+
+	job = g_new0(struct trig_job, 1);
+	job->cmd = TRIG_TOGGLE_SPLIT_VFO;
+	TRTR(0, "#%d: Split VFO %s", trig->nr, gtrigs->split_vfo == RIG_VFO_MAIN ? "MAIN" : "SUB");
+	trig_job_add(trig, job);
+}
+
 void trig_job_add(struct trig *trig, struct trig_job *job){
     MUTEX_LOCK(trig->jobs);
     add_to_list(trig->jobs, job);
@@ -565,83 +603,101 @@ gpointer trig_main(gpointer xxx){
             continue;
         }
 
-        switch(job->cmd){
-            case TRIG_MODE:
-                usleep(trig->poll_ms * 1000);
-                rigerr = rig_get_mode(trig->rig, RIG_VFO_CURR, &mode, &width);
-                if (rigerr != RIG_OK) {
-                    gtrigs->rigerr = trig->rigerr = rigerr;
+		switch (job->cmd){
+			case TRIG_MODE:
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_get_mode(trig->rig, RIG_VFO_CURR, &mode, &width);
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
 					TRTR(1, "rig_get_mode(#%d, RIG_VFO_CURR)", trig->nr);
-                    break;
-                }
-                usleep(trig->poll_ms * 1000);
-                rigerr = rig_set_mode(trig->rig, RIG_VFO_CURR, job->mode, width /*RIG_PASSBAND_NORMAL*/);
+					break;
+				}
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_set_mode(trig->rig, RIG_VFO_CURR, job->mode, width /*RIG_PASSBAND_NORMAL*/);
 				TRTR(1, "rig_set_mode(#%d, RIG_VFO_CURR, %s, %ld)", trig->nr, rig_strrmode(job->mode), width);
-                if (rigerr != RIG_OK) {
-                    gtrigs->rigerr = trig->rigerr = rigerr;
-                    break;
-                }
-                break;
-            
-            case TRIG_FREQ:
-                usleep(trig->poll_ms * 1000);
-                rigerr = rig_set_freq(trig->rig, RIG_VFO_CURR, job->freq);
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+				break;
+
+			case TRIG_FREQ:
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_set_freq(trig->rig, RIG_VFO_CURR, job->freq);
 				TRTR(1, "rig_set_freq(#%d, RIG_VFO_CURR, %8.3f)", trig->nr, job->freq / 1000000.0);
-                if (rigerr != RIG_OK) {
-                    gtrigs->rigerr = trig->rigerr = rigerr;
-                    break;
-                }
-                break;
-            case TRIG_MODE_FREQ:
-                usleep(trig->poll_ms * 1000);
-                rigerr = rig_get_mode(trig->rig, RIG_VFO_CURR, &mode, &width);
-                if (rigerr != RIG_OK) {
-                    gtrigs->rigerr = trig->rigerr = rigerr;
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+				break;
+			case TRIG_MODE_FREQ:
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_get_mode(trig->rig, RIG_VFO_CURR, &mode, &width);
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
 					TRTR(1, "rig_get_mode(#%d, RIG_VFO_CURR)", trig->nr);
-                    break;
-                }
-                //dbg("mode=%d job->mode=%d\n", mode, job->mode);
-                if (mode == job->mode) break;
-                usleep(trig->poll_ms * 1000);
-                rigerr = rig_set_mode(trig->rig, RIG_VFO_CURR, job->mode, width /*RIG_PASSBAND_NORMAL*/);
+					break;
+				}
+				//dbg("mode=%d job->mode=%d\n", mode, job->mode);
+				if (mode == job->mode) break;
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_set_mode(trig->rig, RIG_VFO_CURR, job->mode, width /*RIG_PASSBAND_NORMAL*/);
 				TRTR(1, "rig_set_mode(#%d, RIG_VFO_CURR, %s, %ld", trig->nr, rig_strrmode(job->mode), width);
-                if (rigerr != RIG_OK) {
-                    gtrigs->rigerr = trig->rigerr = rigerr;
-                    break;
-                }
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
 
-                usleep(trig->poll_ms * 1000);
-                rigerr = rig_set_freq(trig->rig, RIG_VFO_CURR, job->freq);
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_set_freq(trig->rig, RIG_VFO_CURR, job->freq);
 				TRTR(1, "rig_set_freq(#%d, RIG_VFO_CURR, %8.3f)", trig->nr, job->freq / 1000000.0);
-//                dbg("set_freq: %8.3f\n", job->freq/1000000.0);
-                if (rigerr != RIG_OK) {
-                    gtrigs->rigerr = trig->rigerr = rigerr;
-                    break;
-                }
-                break;
+				//                dbg("set_freq: %8.3f\n", job->freq/1000000.0);
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+				break;
 
-            case TRIG_RESENDFREQ:
-                zselect_msg_send(zsel, "TRIG;%d;qrg;%"PRIfreq"", trig->nr, freq);
-                zselect_msg_send(zsel, "TRIG;%d;rit;%"PRIfreq"", trig->nr, rit);
-                break;
-            case TRIG_RIT:
-               // dbg("rig_set_rit(#%d,%d, %ld)\n", trig->nr, RIG_VFO_CURR, job->rit);
-                usleep(trig->poll_ms * 1000);
-                rigerr = rig_set_rit(trig->rig, RIG_VFO_CURR, job->rit);
+			case TRIG_RESENDFREQ:
+				zselect_msg_send(zsel, "TRIG;%d;qrg;%"PRIfreq"", trig->nr, freq);
+				zselect_msg_send(zsel, "TRIG;%d;rit;%"PRIfreq"", trig->nr, rit);
+				break;
+			case TRIG_RIT:
+				// dbg("rig_set_rit(#%d,%d, %ld)\n", trig->nr, RIG_VFO_CURR, job->rit);
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_set_rit(trig->rig, RIG_VFO_CURR, job->rit);
 				TRTR(1, "rig_set_rit(#%d, RIG_VFO_CURR, %ld)", trig->nr, job->rit);
-                if (rigerr != RIG_OK) {
-                    gtrigs->rigerr = trig->rigerr = rigerr;
-                    break;
-                }
-                break;
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+				break;
 			case TRIG_PTT:
-                usleep(trig->poll_ms * 1000);
-                rigerr = rig_set_ptt(trig->rig, RIG_VFO_CURR, job->ptt);
+				usleep(trig->poll_ms * 1000);
+				rigerr = rig_set_ptt(trig->rig, RIG_VFO_CURR, job->ptt);
 				TRTR(1, "rig_set_ptt(#%d, RIG_VFO_CURR, %d)", trig->nr, job->ptt);
-                if (rigerr != RIG_OK) {
-                    gtrigs->rigerr = trig->rigerr = rigerr;
-                    break;
-                }
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+				break;
+			case TRIG_TOGGLE_SPLIT_VFO:
+				usleep(trig->poll_ms * 1000);
+				split_t split;
+
+				if (gtrigs->split_vfo == RIG_VFO_MAIN) {
+					split = RIG_SPLIT_OFF;
+				}else{
+					split = RIG_SPLIT_ON;
+				}
+
+				rigerr = rig_set_split_vfo(trig->rig, RIG_VFO_CURR, split, gtrigs->split_vfo);
+				TRTR(1, "rig_set_split_vfo(#%d, RIG_VFO_CURR, %d, %s) ", trig->nr, (int)split, gtrigs->split_vfo == RIG_VFO_MAIN ? "MAIN" : "SUB");
+				if (rigerr != RIG_OK) {
+					gtrigs->rigerr = trig->rigerr = rigerr;
+					break;
+				}
+
 				break;
         }
     }
