@@ -39,7 +39,7 @@ struct config_rig{
 #include <zthread.h>
 
 enum trig_cmd { 
-    TRIG_FREQ, TRIG_MODE, TRIG_MODE_FREQ, TRIG_RESENDFREQ, TRIG_RIT, TRIG_PTT
+    TRIG_FREQ, TRIG_MODE, TRIG_MODE_FREQ, TRIG_RESENDFREQ, TRIG_RIT, TRIG_PTT, TRIG_TOGGLE_SPLIT_VFO
 };
 
 struct trig_job{
@@ -85,6 +85,7 @@ struct trigs{
     shortfreq_t rit;
 	GPtrArray *trigs; // of struct trig
     int rigerr;
+	vfo_t split_vfo;  // accessed from thread
 };
 
 extern struct trigs *gtrigs;
@@ -101,6 +102,7 @@ void trigs_set_qrg_except(struct trigs *trigs, int except_rigr, double qrg);
 void trigs_set_rit_except(struct trigs *trigs, int except_rigr, double rit);
 void trigs_resend_freq(struct trigs *trigs, int rignr);
 void trigs_set_ptt(struct trigs *trigs, int ptt);
+void trigs_toggle_split_vfo(struct trigs *trigs);
 
 
 // trig functions
@@ -117,6 +119,7 @@ void trig_set_mode_qrg(struct trig *trig, rmode_t mode, double qrg);
 void trig_resend_freq(struct trig *trig);
 void trig_set_rit(struct trig *trig, shortfreq_t rit);
 void trig_set_ptt(struct trig *trig, ptt_t ptt);
+void trig_toggle_split_vfo(struct trig *trig);
 
 int trig_save_riglist(const struct rig_caps *caps, void *data);
 int trig_compare (const void *a, const void *b);
