@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2021  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -49,13 +49,43 @@ SDL_Color pal[256];
 int sdl_test(void);
 #endif
 
-#ifdef Z_MSC_MINGW
+#if defined(Z_MSC_MINGW) && defined(Z_HAVE_SDL1)
 int getaltstate(){
 	SHORT ret = GetKeyState(VK_MENU);// Alt key
 	return (ret & 0x8000) != 0;// high-order bit is 1
 }
 #endif
 
+char *dumpmods(SDL_Keysym *sym){
+	static GString *gs = NULL;
+	if (gs == NULL) gs = g_string_sized_new(256);
+	g_string_truncate(gs, 0);
+
+	SDL_Keymod mod;
+	if (sym != NULL)
+		mod = sym->mod;
+	else
+		mod = SDL_GetModState();
+
+	if (mod & KMOD_LSHIFT) g_string_append(gs, "LSHIFT ");
+	if (mod & KMOD_RSHIFT) g_string_append(gs, "RSHIFT ");
+	if (mod & KMOD_LCTRL) g_string_append(gs, "LCTRL ");
+	if (mod & KMOD_RCTRL) g_string_append(gs, "RCTRL ");
+	if (mod & KMOD_LALT) g_string_append(gs, "LALT ");
+	if (mod & KMOD_RALT) g_string_append(gs, "RALT ");
+#ifdef Z_HAVE_SDL2
+	if (mod & KMOD_LGUI) g_string_append(gs, "LGUI ");
+	if (mod & KMOD_RGUI) g_string_append(gs, "RGUI ");
+#endif
+	if (mod & KMOD_NUM) g_string_append(gs, "NUM ");
+	if (mod & KMOD_CAPS) g_string_append(gs, "CAPS ");
+	if (mod & KMOD_MODE) g_string_append(gs, "MODE ");
+#if defined(Z_MSC_MINGW) && defined(Z_HAVE_SDL1)
+	if (getaltstate()) g_string_append(gs, "VK_MENU ");
+#endif
+	return gs->str;
+}
+
 struct tsdl *init_sdl(){
     int w, h, ty;
     SDL_Rect r;
@@ -63,7 +93,12 @@ struct tsdl *init_sdl(){
     SDL_Surface *tucnak64 = NULL;
     time_t now;
     struct tm *tm;
-    const SDL_VideoInfo *vi;
+#ifdef Z_HAVE_SDL1
+	const SDL_VideoInfo *vi;
+#endif
+#ifdef Z_HAVE_SDL2
+	SDL_DisplayMode dm;
+#endif
  
 #ifdef SDLTEST
     exit(sdl_test());
@@ -96,9 +131,13 @@ struct tsdl *init_sdl(){
     sdl=g_new0(struct tsdl, 1);
 	sdl->old_mouse_x = -1;
 	sdl->old_mouse_y = -1;
-
-    sdl->iconv=iconv_open("ISO8859-2","UCS-2LE");
-    if (sdl->iconv==(iconv_t)(-1)){
+#ifdef Z_HAVE_SDL1
+	sdl->iconvhandle = iconv_open("ISO8859-2", "UCS-2LE");
+#endif
+#ifdef Z_HAVE_SDL2
+	sdl->iconvhandle = iconv_open("ISO8859-2", "UTF-8");
+#endif
+	if (sdl->iconvhandle == (iconv_t)(-1)){
         int err=errno;
         char *c = z_strdup_strerror(err);
         dbg("Can't init iconv %s\n", c);
@@ -115,17 +154,27 @@ struct tsdl *init_sdl(){
         return NULL;
     };  
     sdl_pre_info();
+#ifdef Z_HAVE_SDL1
     vi = SDL_GetVideoInfo();
     if (vi){
         sdl->screen_w = vi->current_w;
         sdl->screen_h = vi->current_h;
     }
+#endif
+#ifdef Z_HAVE_SDL2
+	if (SDL_GetCurrentDisplayMode(0/*TODO*/, &dm) == 0){
+		sdl->screen_w = dm.w;
+		sdl->screen_h = dm.h;
+	}
+#endif
 	sdl->window_w = cfg->gfx_x;
 	sdl->window_h = cfg->gfx_y;
 	zsdl_sys_key_repeat(300, 20);
+#ifdef Z_HAVE_SDL1
     SDL_EnableUNICODE(1);
-
+#endif
     
+
 #ifdef Z_HAVE_LIBPNG   
     if ((now&0xf8) == 192){
         sdl->icon = zpng_create(icon_tucnakv, sizeof(icon_tucnakv));
@@ -148,7 +197,6 @@ struct tsdl *init_sdl(){
     if (!sdl->zoomout) zinternal("Can't create icon_zoomout32, corrupted executable?");
     if (!sdl->key) zinternal("Can't create icon_key, corrupted executable?");
     if (!sdl->xfer) zinternal("Can't create icon_xfer, corrupted executable?");
-    SDL_WM_SetIcon(sdl->icon, NULL);
 #endif
 	if (z_pipe(sdl->eventpipe)) {
         zinternal("can't create pipe for internal communication");
@@ -184,6 +232,9 @@ struct tsdl *init_sdl(){
     zsdl_printf(sdl->screen, sdl->screen->w / 2, ty, sdl->gr[12], 0, ZFONT_CENTERX, "Tucnak %s", VERSION);
     SDL_UpdateRect(sdl->screen, 0, 0, w, h);
     rot_update_colors();
+#ifdef Z_HAVE_LIBPNG   
+	SDL_SetWindowIcon(zsdl->window, sdl->icon);
+#endif
     
     /*{
         r.w = 256;
@@ -250,7 +301,7 @@ void free_sdl(){
 
     SDL_Quit();
 
-    if (sdl->iconv) iconv_close(sdl->iconv);
+	if (sdl->iconvhandle) iconv_close(sdl->iconvhandle);
     
     g_free(sdl);
     sdl=NULL;
@@ -259,47 +310,68 @@ void free_sdl(){
 char *sdl_best = NULL;
 
 void sdl_pre_info(){
-    const SDL_VideoInfo *vi;
 	GString *gs = g_string_new("");
 
-    vi = SDL_GetVideoInfo();
-    if (!vi){
-        g_string_append_printf(gs, "No \"best mode\" exists\n");
-    }else{
-        g_string_append_printf(gs, "Screen: %dx%d-%d ", vi->current_w, vi->current_h, vi->vfmt->BitsPerPixel);
-        if (vi->vfmt->palette){
-            g_string_append_printf(gs, "using palette ");
-        }else{
-            g_string_append_printf(gs, "R=%x G=%x B=%x A=%x ", vi->vfmt->Rmask, vi->vfmt->Gmask, vi->vfmt->Bmask, vi->vfmt->Amask);
-        }
-        g_string_append_printf(gs, "colorkey=%04x alpha=%d\n", vi->vfmt->colorkey, vi->vfmt->alpha);
-    }
+#ifdef Z_HAVE_SDL1
+	const SDL_VideoInfo *vi = SDL_GetVideoInfo();
+	if (!vi){
+		g_string_append_printf(gs, "No \"best mode\" exists\n");
+	}
+	else{
+		g_string_append_printf(gs, "Screen: %dx%d-%d ", vi->current_w, vi->current_h, vi->vfmt->BitsPerPixel);
+		if (vi->vfmt->palette){
+			g_string_append_printf(gs, "using palette ");
+		}
+		else{
+			g_string_append_printf(gs, "R=%x G=%x B=%x A=%x ", vi->vfmt->Rmask, vi->vfmt->Gmask, vi->vfmt->Bmask, vi->vfmt->Amask);
+		}
+		g_string_append_printf(gs, "colorkey=%04x alpha=%d\n", vi->vfmt->colorkey, vi->vfmt->alpha);
+	}
+#endif
+#ifdef Z_HAVE_SDL2
+	SDL_DisplayMode dm;
+	int i;
+	for (i = 0; i < SDL_GetNumVideoDisplays(); i++){
+		if (SDL_GetCurrentDisplayMode(i, &dm) == 0){
+			g_string_append_printf(gs, "Screen %d: %dx%d, %d Hz, pixel format %s \n", i, dm.w, dm.h, dm.refresh_rate, SDL_GetPixelFormatName(dm.format));
+		}
+	}
+#endif
+
+   
 	g_free(sdl_best);
 	sdl_best = g_strdup(gs->str);
 	g_string_free(gs, TRUE);
 }
 
 void sdl_info(GString *gs){
-    SDL_Rect **modes;
-    int i;
-    char str[256];
-    int oldw, oldh;
 
-    g_string_append_printf(gs, "\n  sdl_info:\n");
+	g_string_append_printf(gs, "\n  sdl_info:\n");
 
 
-    if (SDL_Init(SDL_INIT_VIDEO) < 0){
-        g_string_append_printf(gs, "SDL_Init failed\n");
-        return;
-    };
-    
-    SDL_VideoDriverName(str, sizeof(str)-1);
-    str[sizeof(str)-1]='\0';
+	if (SDL_Init(SDL_INIT_VIDEO) < 0){
+		g_string_append_printf(gs, "SDL_Init failed\n");
+		return;
+	};
+
+#ifdef Z_HAVE_SDL1
+	char str[256];
+	SDL_VideoDriverName(str, sizeof(str)-1);
+	str[sizeof(str) - 1] = '\0';
+#endif
+#ifdef Z_HAVE_SDL2
+	const char *str = SDL_GetCurrentVideoDriver();
+#endif
+
     if (*str) g_string_append_printf(gs, "Driver: %s\n", str);
 
 	if (!sdl_best) sdl_pre_info();
     g_string_append(gs, sdl_best);
-    
+#ifdef Z_HAVE_SDL1
+	int oldw, oldh;
+	int i;
+	SDL_Rect **modes;
+
     modes=SDL_ListModes(NULL, SDL_FULLSCREEN);
     if (!modes) {
         g_string_append_printf(gs, "No video modes available (SDL_ListModes)\n");
@@ -319,6 +391,19 @@ void sdl_info(GString *gs){
         }
 	    g_string_append_printf(gs, "\n");
     }
+#endif
+#ifdef Z_HAVE_SDL2
+	SDL_DisplayMode dm = { SDL_PIXELFORMAT_UNKNOWN, 0, 0, 0, 0 };
+	for (int di = 0; di < SDL_GetNumVideoDisplays(); di++){
+		g_string_append_printf(gs, "Display %d\n", di);
+
+		for (int mi = 0; mi < SDL_GetNumDisplayModes(di); mi++){
+			if (SDL_GetDisplayMode(di, mi, &dm) != 0) continue;
+			
+			g_string_append_printf(gs, "Mode %d: %dx%d, %d Hz, pixel format %s \n", mi, dm.w, dm.h, dm.refresh_rate, SDL_GetPixelFormatName(dm.format));
+		}
+	}
+#endif
 	g_string_append_printf(gs, "\n");
 }
 
@@ -342,10 +427,21 @@ int sdl_setvideomode(int w, int h, int init_x){
 	if (init_x == 0) cfg->maximized = zsdl_maximized(zsdl, NULL, NULL);
     
 
-	flags = SDL_SWSURFACE|SDL_RESIZABLE|SDL_HWPALETTE;
+	flags = SDL_SWSURFACE;
+#ifdef Z_HAVE_SDL1
+	flags |= SDL_RESIZABLE | SDL_HWPALETTE;
+#endif
+#ifdef Z_HAVE_SDL2
+	flags |= SDL_WINDOW_RESIZABLE;
+#endif
 	if (cfg->fullscreen){
-        flags |= SDL_FULLSCREEN;
-        if (sdl->screen_w > 0 && sdl->screen_h >= 0){
+#ifdef Z_HAVE_SDL1
+		flags |= SDL_FULLSCREEN;
+#endif
+#ifdef Z_HAVE_SDL2
+		flags |= SDL_WINDOW_FULLSCREEN_DESKTOP;
+#endif
+		if (sdl->screen_w > 0 && sdl->screen_h >= 0){
             w = sdl->screen_w;
             h = sdl->screen_h;
 #ifdef Z_ANDROID
@@ -361,15 +457,60 @@ int sdl_setvideomode(int w, int h, int init_x){
 	}
     /*w = 480;
     h = 800;*/
-
+#ifdef Z_HAVE_SDL1
 	dbg("SDL_SetVideoMode(%d,%d)\n", w, h);
 	sdl->screen = SDL_SetVideoMode(w, h, 0, flags);
 	if (sdl->screen == NULL){
 		dbg("SDL_SetVideoMode(%d,%d) failed\n", w, h);
 		return 1;    
 	}
+	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse);
+
+#endif
+#ifdef Z_HAVE_SDL2
+	dbg("SDL_CreateWindow(%d,%d)\n", w, h);
+
+	/*if (zsdl != NULL && zsdl->window != NULL){
+		SDL_DestroyWindow(zsdl->window);
+		zsdl->window = NULL;
+	}
+	
+	SDL_Window *win = SDL_CreateWindow("Tucnak "PACKAGE_VERSION, SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED, w, h, flags);
+	if (win == NULL){
+		dbg("SDL_CreateWindow(%d,%d) failed\n", w, h);
+		return 1;
+	} */
+
+	SDL_Window *win = NULL;
+	if (zsdl != NULL) win = zsdl->window;
+
+	if (zsdl == NULL || zsdl->window == NULL){
+		win = SDL_CreateWindow("Tucnak "PACKAGE_VERSION, SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED, w, h, flags);
+		if (win == NULL){
+			dbg("SDL_CreateWindow(%d,%d) failed\n", w, h);
+			return 1;
+		}
+	}
+	
+
+	Uint32 format = SDL_GetWindowPixelFormat(win);
+	SDL_PixelFormat *pxformat = SDL_AllocFormat(format);
+
+	//sdl->screen = SDL_CreateRGBSurface(SDL_SWSURFACE, w, h, pxformat->BitsPerPixel, pxformat->Rmask, pxformat->Gmask, pxformat->Bmask, pxformat->Amask);
+	sdl->screen = SDL_GetWindowSurface(win);
 
 	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse);
+	zsdl->window = win;
+	zsdl->format = format;
+	zsdl->pxformat = pxformat;
+	
+	/*SDL_SetWindowResizable(zsdl->window, SDL_TRUE);
+	if (cfg->fullscreen){
+		SDL_SetWindowFullscreen(zsdl->window, SDL_TRUE);
+	}*/
+	//SDL_StartTextInput();
+#endif
+
     //if (SDL_MUSTLOCK(sdl->screen)) zinternal("surface must be locked");
     sdl->termarea.x = 0;
     sdl->termarea.y = 0;
@@ -385,9 +526,13 @@ int sdl_setvideomode(int w, int h, int init_x){
             sdl->colors[i].g=((i<<3)&0xe0)+31;
             sdl->colors[i].b=((i<<6)&0xc0)+63;
         }
+#ifdef Z_HAVE_SDL1
         SDL_SetColors(sdl->screen, sdl->colors, 0, 256);
-
-        fmt=sdl->screen->format;
+#endif
+#ifdef Z_HAVE_SDL2
+		SDL_SetPaletteColors(zsdl->screen->format->palette, sdl->colors, 0, 256);
+#endif
+		fmt = sdl->screen->format;
         fmt->Rmask=0xe0;
         fmt->Gmask=0x1c;
         fmt->Bmask=0x03;
@@ -747,24 +892,32 @@ int sdl_get_terminal_size(int fd, int *x, int *y){
 }
 
 int handle_unicode(const SDL_Event *sev, struct event *ev){
-    char iso[10];
-    char uni[2];
+    char iso[64];
     char *isoptr;
     char *uniptr;
     size_t in,out;
     int ret;
 
-    if (!sev->key.keysym.unicode) return 0;
-    
-    in=2;
-    out=10;
-    uni[0]=sev->key.keysym.unicode & 0xff;
-    uni[1]=sev->key.keysym.unicode >> 8;
+#ifdef Z_HAVE_SDL1
+	char uni[2];
+	if (!sev->key.keysym.unicode) return 0;
+	uni[0] = sev->key.keysym.unicode & 0xff;
+	uni[1] = sev->key.keysym.unicode >> 8;
+	in = 2;
+#endif
+#ifdef Z_HAVE_SDL2
+	char uni[64];
+	strcpy(uni, sev->text.text);
+	in = strlen(uni);
+#endif
+	out = sizeof(iso);
+
     isoptr=iso;
     uniptr=uni;
     
     /*dbg("uniptr=%p isoptr=%p in=%d out=%d\n", uniptr, isoptr, in, out);*/
-    ret=iconv(sdl->iconv, &uniptr, &in, &isoptr, &out);
+
+	ret = iconv(sdl->iconvhandle, &uniptr, &in, &isoptr, &out);
     //err=errno;
     /*dbg("uniptr=%p isoptr=%p in=%d out=%d\n", uniptr, isoptr, in, out);*/
     
@@ -772,29 +925,40 @@ int handle_unicode(const SDL_Event *sev, struct event *ev){
         //rintf(stderr, "Keyboard: unicode=0x%04x  iso:0x%02x '%c'\n", sev->key.keysym.unicode, (unsigned char)iso[0],isprint((unsigned char)iso[0])?(unsigned char)iso[0]:'.');
     }
     if (ret || !iso[0]){
-        log_addf("Can't handle keystroke unicode=0x%04x  ret=%d  iso=0x%02x\n", sev->key.keysym.unicode, ret, (unsigned char)iso[0]);
-        return 0;
+		int err=errno;
+		char *c = z_strdup_strerror(err);
+#ifdef Z_HAVE_SDL1
+        log_addf("Can't handle keystroke unicode=0x%04x  error=%s  iso=0x%02x\n", sev->key.keysym.unicode, c, (unsigned char)iso[0]);
+#endif
+#ifdef Z_HAVE_SDL2
+		log_addf("Can't handle keystroke unicode='%s'  error=%s  iso=0x%02x\n", sev->text.text, c, (unsigned char)iso[0]);
+#endif
+		g_free(c);
+		return 0;
     }
 
+	//dbg("TEXTINPUT %c (%s)\n", (unsigned char)iso[0], dumpmods(NULL));
+
     ev->x=(unsigned char)iso[0];
     if (ev->x <= 26){    /* Ctrl+letter */
         ev->x +='@';
     }
 	if (ev->x == 31) ev->x = '-';
 
-    /*if (sev->key.keysym.mod & KMOD_SHIFT)           ev->y|=KBD_SHIFT;*/
-	if ((sev->key.keysym.mod & (KMOD_LCTRL|KMOD_RALT)) != (KMOD_LCTRL|KMOD_RALT)){ // skip right alt which switches keyboard layout for accent
-#ifdef Z_MSC_MINGW
-		if (getaltstate()) ev->y|=KBD_ALT;
-		if (sev->key.keysym.mod & (KMOD_ALT|KMOD_META)){
-			if (getaltstate() == 0) {
-				int x = 0;
-			}
-		}
-#else
-		if (sev->key.keysym.mod & (KMOD_ALT|KMOD_META)) ev->y|=KBD_ALT;
+
+#ifdef Z_HAVE_SDL1
+	SDL_Keymod mod = sev->key.keysym.mod;
 #endif
-		if (sev->key.keysym.mod & KMOD_CTRL)            ev->y|=KBD_CTRL;
+#ifdef Z_HAVE_SDL2
+	SDL_Keymod mod = SDL_GetModState();
+#endif
+	if ((mod & (KMOD_LCTRL|KMOD_RALT)) != (KMOD_LCTRL|KMOD_RALT)){ // skip right alt which switches keyboard layout for accent
+#if defined(Z_MSC_MINGW) && defined(Z_HAVE_SDL1)
+		if (getaltstate()) ev->y|=KBD_ALT;
+#else
+		if (mod & (KMOD_ALT|KMOD_META)) ev->y|=KBD_ALT;
+#endif
+		if (mod & KMOD_CTRL)            ev->y|=KBD_CTRL;
 	}
 
     return 1;
@@ -805,7 +969,6 @@ gpointer sdl_event_thread(gpointer handle){
     SDL_Event sev, sev2;
     struct event ev;
     int shift,k,sk,ret;
-    int skip_unicode = 0;
     struct timeval oldmtv, now;
     int oldmx = -1, oldmy = -1;
     double d;
@@ -832,8 +995,15 @@ gpointer sdl_event_thread(gpointer handle){
 #ifndef EVENTS_IN_SAME_THREAD
 		SDL_PumpEvents();
 #endif
+
+
+#ifdef Z_HAVE_SDL1
 		switch(SDL_PeepEvents(&sev, 1, SDL_GETEVENT, SDL_ALLEVENTS)) {
-		    case -1: 
+#endif
+#ifdef Z_HAVE_SDL2
+		switch (SDL_PeepEvents(&sev, 1, SDL_GETEVENT, SDL_FIRSTEVENT, SDL_LASTEVENT)) {
+#endif
+		    case -1:
                 return GINT_TO_POINTER(-1);
                 break;
 		    case 0: 
@@ -842,6 +1012,8 @@ gpointer sdl_event_thread(gpointer handle){
 		    case 1: 
                 break;
 		}
+
+
 #if 0
         switch (sev.type){
             case SDL_NOEVENT: dbg("SDL_NOEVENT\n"); break;
@@ -859,44 +1031,25 @@ gpointer sdl_event_thread(gpointer handle){
         }
 #endif
 
-		if (sev.type == SDL_KEYDOWN || sev.type == SDL_KEYUP){
-			//dbg("%s ",  sev.type == SDL_KEYDOWN ? "DOWN" : " UP ");
-			/*switch (sev.key.keysym.sym){
-				case SDLK_LALT: dbg("LALT"); break;
-				case SDLK_TAB: dbg("TAB"); break;
-				case SDLK_a: dbg("a"); break;
-			}*/
-			//dbg("  mod=%x\n", sev.key.keysym.mod);
-		}
+		
         
         switch(sev.type){
-            case SDL_KEYDOWN:
-#if 0
-                dbg("KEYDOWN: ");
-                for (k=0;k<sizeof(sev);k++) {
-                    char *c;
-                    c=(char *)&sev;
-                    dbg ("%02x ", (unsigned char) (c[k]));
-                }
-                dbg("\n");
+#ifdef Z_HAVE_SDL2
+			case SDL_TEXTINPUT:
+				//dbg("TEXTINPUT: '%s'\n", sev.text.text);
+				ev.ev = EV_KBD;
+				if (handle_unicode(&sev, &ev)) goto sendkeydown;
+
+				dbg("to je divny, SDL_TEXTINPUT '%s' nebyla zpracovana\n", sev.text.text);
+				break;
 #endif
-#if 0
-                //kev=&sev;
-    
-                dbg("type=%d state=%d scan=%d sym=%d mod=%d unicode=%d    altstate=0x%x\n",  
-                        sev.key.type, sev.key.state, sev.key.keysym.scancode, sev.key.keysym.sym, sev.key.keysym.mod, sev.key.keysym.unicode,
-						getaltstate());
-                //dbg("%d %d\n", SDLK_LCTRL, SDLK_RCTRL);
-				if (sev.key.keysym.unicode == 43){
-					int aaa = 0;
-				}
+            case SDL_KEYDOWN:
+#if 1
+				//if (sev.key.keysym.sym != SDLK_LCTRL && sev.key.keysym.sym != SDLK_RCTRL && sev.key.keysym.sym != SDLK_LALT && sev.key.keysym.sym != SDLK_RALT && sev.key.keysym.sym != SDLK_LSHIFT && sev.key.keysym.sym != SDLK_RSHIFT)
+					//dbg("KEYDOWN: scan=%d sym=%d '%c' mod=%d (%s)   GetMods=(%s)\n", sev.key.keysym.scancode, sev.key.keysym.sym, sev.key.keysym.sym, sev.key.keysym.mod, dumpmods(&sev.key.keysym), dumpmods(NULL));
 #endif                
 
-				if (sev.key.keysym.sym == SDLK_LCTRL || sev.key.keysym.sym == SDLK_RCTRL) {
-                    //dbg("ctrl 111111111111111\n");
-                    sdl->ctrl = 1;
-                }
-                if (cfg->altsyms){
+				if (cfg->altsyms){
                     oldaltsym = sdl->altsym;
                     if (sev.key.keysym.sym == SDLK_LALT || sev.key.keysym.sym == SDLK_RALT){
                         sdl->altsym = 1;
@@ -908,13 +1061,6 @@ gpointer sdl_event_thread(gpointer handle){
                 }    
                 
                 ev.ev=EV_KBD;
-#if 0
-                if (sev.key.keysym.sym < 256)
-                    log_addf("SDL_KEYDOWN->EV_KBD: mod=%x sym=%d='%c'", sev.key.keysym.mod, sev.key.keysym.sym, sev.key.keysym.sym);
-                else
-                    log_addf("SDL_KEYDOWN->EV_KBD: mod=%x sym=%d", sev.key.keysym.mod, sev.key.keysym.sym);
-#endif
-
                 switch(sev.key.keysym.sym){
                     case SDLK_BACKSPACE:    k=sk=KBD_BS;         goto handle;                                            
                     case SDLK_TAB:          k=sk=KBD_TAB;        goto handle;
@@ -945,6 +1091,7 @@ gpointer sdl_event_thread(gpointer handle){
                     case SDLK_F10: 		    k=sk=KBD_F10;        goto handle;
                     case SDLK_F11: 		    k=sk=KBD_F11;        goto handle;
                     case SDLK_F12: 		    k=sk=KBD_F12;        goto handle;
+#ifdef Z_HAVE_SDL1
                     case SDLK_KP0:          k=KBD_INS;   sk='0'; goto handle;
                     case SDLK_KP1:          k=KBD_END;   sk='1'; goto handle;
                     case SDLK_KP2:          k=KBD_DOWN;  sk='2'; goto handle;
@@ -955,28 +1102,49 @@ gpointer sdl_event_thread(gpointer handle){
                     case SDLK_KP7:          k=KBD_HOME;  sk='7'; goto handle;
                     case SDLK_KP8:          k=KBD_UP;    sk='8'; goto handle;
                     case SDLK_KP9:          k=KBD_PGUP;  sk='9'; goto handle;
-                    case SDLK_KP_PERIOD:    k=KBD_DEL;   sk='.'; goto handle;
-                    case SDLK_KP_DIVIDE:    k=sk='/';            goto handle;
-                    case SDLK_KP_MULTIPLY: 	k=sk='*';            goto handle;
-                    case SDLK_KP_MINUS: 	k=sk='-';            goto handle;
-                    case SDLK_KP_PLUS: 	    k=sk='+';            goto handle;
+#endif
+#ifdef Z_HAVE_SDL2 // special handled by TEXTINPUT, number here
+					case SDLK_KP_0:          k = KBD_INS;   goto handle;
+					case SDLK_KP_1:          k = KBD_END;   goto handle;
+					case SDLK_KP_2:          k = KBD_DOWN;  goto handle;
+					case SDLK_KP_3:          k = KBD_PGDN;  goto handle;
+					case SDLK_KP_4:          k = KBD_LEFT;  goto handle;
+					case SDLK_KP_5:          k = KBD_DOWN;  goto handle;
+					case SDLK_KP_6:          k = KBD_RIGHT; goto handle;
+					case SDLK_KP_7:          k = KBD_HOME;  goto handle;
+					case SDLK_KP_8:          k = KBD_UP;    goto handle;
+					case SDLK_KP_9:          k = KBD_PGUP;  goto handle;
+#endif
+#ifdef Z_HAVE_SDL1
+					case SDLK_KP_PERIOD:     k = KBD_DEL;   sk='.'; goto handle; // jeste je SDLK_PERIOD
+					case SDLK_KP_DIVIDE:     k = sk = '/';          goto handle;
+					case SDLK_KP_MULTIPLY:   k = sk = '*';          goto handle;
+                    case SDLK_KP_MINUS: 	 k = sk = '-';          goto handle;
+                    case SDLK_KP_PLUS: 	     k = sk = '+';          goto handle;
+#endif
 					case SDLK_BACKQUOTE:    k = '`'; sk = '~';   goto handle;
                     default: break;
                 }
 
-                skip_unicode = 0;
+                int skip_unicode = 0;
                 if (sev.key.keysym.sym >= SDLK_0 && sev.key.keysym.sym <= SDLK_9 
 					&& sev.key.keysym.mod & KMOD_CTRL    // Ctrl+3 to Ctrl+9 send strange unicode values
 					&& (sev.key.keysym.mod & KMOD_RALT) == 0) { // but right Alt sets LCTRL | RALT
 						skip_unicode = 1; 
 				}
-
+#ifdef Z_HAVE_SDL1
                 if (sev.key.keysym.unicode && !skip_unicode){
                     if (handle_unicode(&sev, &ev)) goto sendkeydown;
                     dbg("to je divny, unicode 0x%04x nebyla zpracovana\n", sev.key.keysym.unicode);
                 }
-
-                switch(sev.key.keysym.sym){
+#endif
+#ifdef Z_HAVE_SDL2
+				if ((sev.key.keysym.mod & (KMOD_CTRL | KMOD_ALT)) == 0){
+					break;
+				}
+                skip_unicode = skip_unicode; // disable warning
+#endif
+				switch(sev.key.keysym.sym){
                     case SDLK_QUOTE:        k='\'';  sk='"';     break;
                     case SDLK_COMMA:        k=',';   sk='<';     break;
                     case SDLK_MINUS:        k='-';   sk='_';     break;
@@ -1012,20 +1180,27 @@ gpointer sdl_event_thread(gpointer handle){
                         }
                         break;
                 }
-handle:;            
-                shift=(sev.key.keysym.mod & KMOD_SHIFT)!=0;
-                /*dbg("\nshift=%d caps=%d %d\n", shift,sev.key.keysym.mod & KMOD_CAPS,(sev.key.keysym.mod & KMOD_CAPS)!=0 );*/
+			handle:;
+                shift = (sev.key.keysym.mod & KMOD_SHIFT) != 0;
                 if (k>='a' && k<='z') shift^=(sev.key.keysym.mod & KMOD_CAPS)!=0;
+#ifdef Z_HAVE_SDL1
                 if (sev.key.keysym.sym>=SDLK_KP0 && sev.key.keysym.sym<=SDLK_KP_PERIOD) shift^=(sev.key.keysym.mod & KMOD_NUM)!=0;
-                
+#endif
+#ifdef Z_HAVE_SDL2
+				if (sev.key.keysym.sym >= SDLK_KP_1 && sev.key.keysym.sym <= SDLK_KP_PERIOD)
+					shift ^= (sev.key.keysym.mod & KMOD_NUM) != 0;
+#endif
+				
+
                 if (shift){
+					if (sk == 0) break; // handled by TEXTINPUT
                     ev.x=sk; 
                     if (sk>=256) ev.y|=KBD_SHIFT;
                 }else{
                     ev.x=k;
                 }
 
-#ifdef Z_MSC_MINGW
+#if defined(Z_MSC_MINGW) && defined(Z_HAVE_SDL1)
 				if (getaltstate()) ev.y|=KBD_ALT;
                 if (sev.key.keysym.mod & (KMOD_LALT|KMOD_META)){
 					if (!getaltstate()){
@@ -1049,12 +1224,7 @@ handle:;
                 if (ev.x) goto sendkeydown;
                 break;
             case SDL_KEYUP:
-
-                if (sev.key.keysym.sym == SDLK_LCTRL || sev.key.keysym.sym == SDLK_RCTRL) {
-                    //dbg("ctrl 000000000000000\n");
-                    sdl->ctrl = 0;
-                }
-                break;
+				break;
 
             case SDL_MOUSEBUTTONDOWN:
                 ev.ev=EV_MOUSE;
@@ -1077,10 +1247,32 @@ handle:;
                         sdl->mouse_drag=1;
                         sdl->drag_buttons=ev.b=B_RIGHT;   
                         goto send;
+#ifdef Z_HAVE_SDL1
                     case SDL_BUTTON_WHEELUP:   ev.b=B_WHUP;    goto send;
                     case SDL_BUTTON_WHEELDOWN: ev.b=B_WHDOWN;  goto send;
+#endif
                 }
                 break;
+#ifdef Z_HAVE_SDL2
+			case SDL_MOUSEWHEEL:
+				ev.ev = EV_MOUSE;
+				ev.x = sdl->mouse_x / FONT_W;
+				ev.y = sdl->mouse_y / FONT_H;
+				ev.mx = sdl->mouse_x;
+				ev.my = sdl->mouse_y;
+				sdl->old_mouse_x = ev.x;
+				sdl->old_mouse_y = ev.y;
+
+				if (sev.wheel.y > 0){
+					ev.b = B_WHUP;
+					goto send;
+				}
+				if (sev.wheel.y < 0){
+					ev.b = B_WHDOWN;
+					goto send;
+				}
+				break;
+#endif
 
             case SDL_MOUSEBUTTONUP:
                 sdl->mouse_drag=0;
@@ -1119,12 +1311,21 @@ handle:;
                 sdl->mouse_y=sev.button.y;
                 while (1){
 //					dbg("while &sev2=%p\n", &sev2);
+#ifdef Z_HAVE_SDL1
 					ret = SDL_PeepEvents(&sev2, 1, SDL_PEEKEVENT, SDL_ALLEVENTS);
-//			        dbg("PeepEvent2=%d %d\n", ret, sev2.type);
+#endif
+#ifdef Z_HAVE_SDL2
+					ret = SDL_PeepEvents(&sev2, 1, SDL_PEEKEVENT, SDL_FIRSTEVENT, SDL_LASTEVENT);
+#endif
+					//			        dbg("PeepEvent2=%d %d\n", ret, sev2.type);
 					if (ret != 1) break;
                     if (sev2.type!=SDL_MOUSEMOTION) break;
-		            ret=SDL_PeepEvents(&sev, 1, SDL_GETEVENT, SDL_ALLEVENTS);
-
+#ifdef Z_HAVE_SDL1
+					ret = SDL_PeepEvents(&sev, 1, SDL_GETEVENT, SDL_ALLEVENTS);
+#endif
+#ifdef Z_HAVE_SDL2
+					ret = SDL_PeepEvents(&sev, 1, SDL_GETEVENT, SDL_FIRSTEVENT, SDL_LASTEVENT);
+#endif
                     if (ret!=1) zinternal("Somebody stole my event");
  //   		        dbg("PeepEvent3 %d\n", sev.type);
                     ev.x=sev2.button.x/FONT_W;
@@ -1139,7 +1340,7 @@ handle:;
                 if (sdl->mouse_drag) goto send;
                 continue;
                 
-
+#ifdef Z_HAVE_SDL1
             case SDL_VIDEORESIZE:
 				ev.ev=EV_SDLRESIZE;
 				ev.mx = sdl->resize_w = sev.resize.w;
@@ -1149,7 +1350,22 @@ handle:;
 				dbg("SDL_VIDEORESIZE %d w=%d\n", sdl->resizeevents, sdl->resize_w);
 				if (sdl->resizeevents > 0) continue;
 				goto send;
-                
+#endif
+#ifdef Z_HAVE_SDL2
+			case SDL_WINDOWEVENT:
+				if (sev.window.event == SDL_WINDOWEVENT_SIZE_CHANGED){
+					ev.ev = EV_SDLRESIZE;
+					ev.mx = sdl->resize_w = sev.window.data1;
+					ev.my = sdl->resize_h = sev.window.data2;
+					ev.x = ev.mx / FONT_W;
+					ev.y = ev.my / FONT_H;
+					dbg("SDL_WINDOWEVENT_RESIZED %d w=%d\n", sdl->resizeevents, sdl->resize_w);
+					if (sdl->resizeevents > 0) continue;
+					goto send;
+				}
+				break;
+#endif
+
 			case SDL_QUIT:
                 ev.ev=EV_KBD;
                 ev.x='q';
@@ -1179,6 +1395,11 @@ sendkeydown:
                 dbg("altsym remap %c->%c\n", oldk, ev.x);
             }
         }
+#ifdef Z_HAVE_SDL2
+		//dbg("(%s) EV_KBD %d '%c' %s %s %s\n\n", sev.type == SDL_TEXTINPUT ? "TEXTINPUT" : (sev.type == SDL_KEYDOWN ? "KEYDOWN" : "?"), 
+		//	ev.x, ev.x, ev.y & KBD_SHIFT ? "SHIFT" : "", ev.y & KBD_CTRL ? "CTRL" : "", ev.y & KBD_ALT ? "ALT" : "");
+#endif
+
 		goto send;
 send_mouse:;
         gettimeofday(&now, NULL); 
@@ -1204,7 +1425,7 @@ send:;
             len=sdl->eventpipestate;
             MUTEX_UNLOCK(sdl->eventpipestate);
             if (len<sizeof(ev)*5) break;
-            dbg("waiting for the sun %d\n", len);
+            //dbg("waiting for the sun %d\n", len);
             usleep(100000);
 			if (sdl->event_thread_break) goto terminate;
         }
@@ -1268,8 +1489,9 @@ int sdl_set_title(gchar *title){
     if (!sdl) return 0;
     zg_free0(sdl->title);
     sdl->title=g_strdup(title);
-
+#ifdef Z_HAVE_SDL1
     SDL_WM_SetCaption(sdl->title, NULL);
+#endif
     return 0;
 }
 
