@@ -33,7 +33,7 @@
 struct tsdl{
     SDL_Surface *screen;
 	int fullscreen;
-    SDL_Surface *icon, *mast, *home, *zoomin, *zoomout, *key, *xfer;
+	SDL_Surface *icon, *mast, *home, *zoomin, *zoomout, *key, *xfer;
     int bpp;
     SDL_Color colors[256];
     SDL_Rect termarea;
@@ -54,7 +54,7 @@ struct tsdl{
     gchar *title;
     int mouse_x, mouse_y;
     int eventpipe[2];
-    iconv_t iconv;
+    iconv_t iconvhandle;
 #ifdef EVENTS_IN_SAME_THREAD
 	int event_timer_id;
 #endif
@@ -63,7 +63,6 @@ struct tsdl{
 	int window_w, window_h;
 	int old_mouse_x, old_mouse_y;
     int altsym;
-    int ctrl;
 	int ignore_progress;
 };
 
