@@ -20,7 +20,9 @@ int ttys_free   (struct cwdaemon *);
 int ttys_reset  (struct cwdaemon *);
 int ttys_cw     (struct cwdaemon *, int onoff);
 int ttys_ptt    (struct cwdaemon *, int onoff);
-int ttys_ssbway (struct cwdaemon *, int onoff);
+int ttys_cw_single(struct cwdaemon *, int onoff);
+int ttys_ptt_single(struct cwdaemon *, int onoff);
+int ttys_ssbway(struct cwdaemon *, int onoff);
 
 
 #endif
