@@ -135,8 +135,9 @@ int winkey_open(struct cwdaemon *cwda, int verbose){
     // set PTT lead in 
     s[0] = '\04';
     s[1] = cfg->cwda_leadin / 10;
-    s[2] = '\x01';                  // \x00 means something strange, see winkeyusbman.pdf 
-    winkey_write(cwda, s, 3);
+	s[2] = cfg->cwda_tail / 10;
+    //s[2] = '\x01';                  // \x00 means something strange, see winkeyusbman.pdf  
+	winkey_write(cwda, s, 3);
     
     cwda->zser_fd = zserial_fd(cwda->zser);
     zselect_set(zsel, cwda->zser_fd, winkey_read_handler, NULL, NULL, cwda); 
